<?php
namespace Teknisa\FIS\Controllers;

use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request\Row;
use Teknisa\FIS\Services\ArquivosService;

/**
 * Class ArquivosController
 * @package Teknisa\FIS\Controllers
 */
class ArquivosController {

    /**
     * @param ArquivosService $arquivosService
     */
    public function __construct(ArquivosService $arquivosService) {
        $this->arquivosService  = $arquivosService;
    }

    /**
     * Download Arquivo
     * @param Row $dataset
     * @param Response $response
     */
    public function downloadArquivo(Row $dataset, Response $response) {
        try {
            // Dados do Registro
            $row = $dataset->getRow();

            // Arquivo para Download [Nome + Extensão]
            $arquivo = sys_get_temp_dir() . DIRECTORY_SEPARATOR . $row['DSARQUIVO'];

            // Download Arquivo
            $this->arquivosService->downloadArquivo($arquivo);

        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function downloadArquivoAgendamento(Row $dataset, Response $response) {
        try {
            // Dados do Registro
            $row = $dataset->getRow();

            // Arquivo para Download [Nome + Extensão]
            $arquivo = $row['DSARQUIVO'];

            // Download Arquivo
            $this->arquivosService->downloadArquivoAgendamento($arquivo);

        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function downloadArquivoApuracao(Row $dataset, Response $response) {
        try {
            // Dados do Registro
            $row = $dataset->getRow();

            // Arquivo para Download [Nome + Extensão]
            
            $arquivo = $row['NMPATHARQ'];
            $fileName = $row['NMARQUIVO'].'.'.(strtolower(substr(strrchr(basename($arquivo),"."),1)));
            
            // Download Arquivo
            $this->arquivosService->downloadArquivoApuracao($arquivo,$fileName);

        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function downloadArquivoAgendamentoFileServer(Row $dataset, Response $response) {
        try {
            // Dados do Registro
            $row = $dataset->getRow();

            // Arquivo para Download [Nome + Extensão]
            
            $arquivo = $row['PATH'];
            $fileName = $row['NMARQUIVO'];
            // Download Arquivo
            $this->arquivosService->downloadArquivoAgendamentoFileServer($arquivo,$fileName);

        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function downloadArquivoApuracaoFileServer(Row $dataset, Response $response) {
        try {
            // Dados do Registro
            $row = $dataset->getRow();

            // Arquivo para Download [Nome + Extensão]
            
            $arquivo = $row['PATH'];
            $fileName = $row['NMARQUIVO'].'.'.(strtolower(substr(strrchr(basename($arquivo),"."),1)));
            // Download Arquivo
            $this->arquivosService->downloadArquivoAgendamentoFileServer($arquivo,$fileName);

        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
}