<?php
namespace Teknisa\FIS\Modules\Acessorias\Factories;

use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;

class Fis41200ConfiguracaoFactory {

    protected $connection;

    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
    }

    public function insertContaApurac($row) {
        $sql = "INSERT INTO CONTATOAPURAC 
                   ( NRSEQUCONT,
                	 NMCONTATO,
                	 EMAIL,
                	 CDIMPOSTO,
                	 CDEMPRESA,
                	 CDINSCRICAO,
                	 NRORG,
                	 IDAPURAAUTO,
                	 IDEXPORTAUTO
                     ) VALUES ( 
                		 :NRSEQUCONT,
                		 :NMCONTATO,
                		 :EMAIL,
                		 :CDIMPOSTO,
                		 :CDEMPRESA,
                		 :CDINSCRICAO,
                		 :NRORG,
                		 :IDAPURAAUTO,
                		 :IDEXPORTAUTO
                	)";
        
        $params = array(
            "NRSEQUCONT"=>$row["NRSEQUCONT"],
            "NMCONTATO"=>$row["NMCONTATO"],
            "EMAIL"=>$row["EMAIL"],
            "CDIMPOSTO"=>isset($row["CDIMPOSTO"]) ? $row["CDIMPOSTO"] : null,
            "CDEMPRESA"=>$row["CDEMPRESA"],
            "CDINSCRICAO"=>isset($row["CDINSCRICAO"]) ? $row["CDINSCRICAO"] : null,
            "NRORG"=>$row["NRORG"],
            "IDAPURAAUTO"=>$row["IDAPURAAUTO"],
            "IDEXPORTAUTO"=>$row["IDEXPORTAUTO"]
        );
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function updateContaApurac($verificaContaApurac, $row) {
        $sql = "UPDATE CONTATOAPURAC 
                   SET NMCONTATO = :NMCONTATO,
                	 EMAIL = :EMAIL,
                	 CDIMPOSTO = :CDIMPOSTO,
                	 CDEMPRESA = :CDEMPRESA,
                	 CDINSCRICAO = :CDINSCRICAO,
                	 NRORG = :NRORG,
                	 IDAPURAAUTO = :IDAPURAAUTO,
                	 IDEXPORTAUTO = :IDEXPORTAUTO
                     WHERE 
                		 NRSEQUCONT = :NRSEQUCONT";
        
        $params = array(
            "NRSEQUCONT"=>$verificaContaApurac["NRSEQUCONT"],
            "NMCONTATO"=>$verificaContaApurac["NMCONTATO"],
            "EMAIL"=>$verificaContaApurac["EMAIL"],
            "CDIMPOSTO"=>isset($verificaContaApurac["CDIMPOSTO"]) ? $verificaContaApurac["CDIMPOSTO"] : null,
            "CDEMPRESA"=>$verificaContaApurac["CDEMPRESA"],
            "CDINSCRICAO"=>isset($verificaContaApurac["CDINSCRICAO"]) ? $verificaContaApurac["CDINSCRICAO"] : null,
            "NRORG"=>$verificaContaApurac["NRORG"],
            "IDAPURAAUTO"=>$row["IDAPURAAUTO"],
            "IDEXPORTAUTO"=>$row["IDEXPORTAUTO"]
        );
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function getEmpresas($row) {
        // Query a ser executada.
        $sql = "SELECT CDEMPRESA FROM EMPRESA
                    WHERE NRORG = :NRORG
                    ORDER BY CDEMPRESA";
        
        $params = array(
            "NRORG"=> $row["NRORG"]
        );
        
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
        // Executa um fetch no primeiro dado, retornando-o.
        //var_dump($std->fetchAll());
        return $std->fetchAll();
    }
    
    public function verificaContaApurac($row) {
        // Query a ser executada.
        $sql = "SELECT * FROM CONTATOAPURAC
                    WHERE NRORG = :NRORG
                    AND CDEMPRESA = :CDEMPRESA
                    AND NMCONTATO = :NMCONTATO
                    AND EMAIL = :EMAIL";
        
        $params = array(
            "NRORG"=> $row["NRORG"],
            "CDEMPRESA"=> $row["CDEMPRESA"],
            "NMCONTATO"=> $row["NMCONTATO"],
            "EMAIL"=> $row["EMAIL"]
        );
        
        // Prepara o statement da query para execução.
        $std = $this->connection->prepare($sql);
        
        // Executa o statement com os paràmetros passados.
        $std->execute($params);
        
        // Executa um fetch no primeiro dado, retornando-o.
        //var_dump($std->fetchAll());
        return $std->fetchAll();
    }
    
}
