<?php
namespace Teknisa\FIS\Modules\Acessorias\Services;

use Teknisa\FIS\Modules\Acessorias\Services\Jenkins;

class Jobs extends Jenkins
{	
    const TYPE_JOB_FREE_STYLE = 'hudson.model.FreeStyleProject';
    const TYPE_JOB_MAVEN = 'hudson.maven.MavenModuleSet';
    const TYPE_JOB_MULT_CONF = 'hudson.matrix.MatrixProject';
    const TYPE_JOB_EXTERNAL = 'hudson.model.ExternalJob';
    const TYPE_JOB_COPY = 'copy';
    
    const HTTP = array(
        "400" => "Bad Request",
        "401" => "Unauthorized",
        "402" => "Payment Required",
        "403" => "Forbidden",
        "404" => "Not Found",
        "405" => "Method Not Allowed",
        "406" => "Not Acceptable",
        "407" => "Proxy Authentication Required",
        "408" => "Request Timeout",
        "409" => "Conflict",
        "410" => "Gone",
        "411" => "Length Required",
        "412" => "Precondition Failed",
        "413" => "Request Entity Too Large",
        "414" => "Request-URI Too Long",
        "415" => "Unsupported Media Type",
        "416" => "Requested Range Not Satisfiable",
        "417" => "Expectation Failed",
    );
    
    public function createJob()
    {
        try {
            if ($this->getSubmit() === null)
                $this->setSubmit('OK');

            $fieldsRequest = array('name' => array($this->getName()),
                'mode' => array($this->getType()),
                'from' => array($this->getFrom()),
                'json' => array('{
                            "name": "' . $this->getName() . '",
                            "mode": "' . $this->getType() . '",
                            "from": "' . $this->getFrom() . '",
                            "Submit": "' . $this->getSubmit() . '"
                          }'),
                'Submit' => array($this->getSubmit())
            );

            $urlEncoded = self::encodeUrl($fieldsRequest);
            
            $curl = curl_init();
            curl_setopt($curl, CURLOPT_URL, $this->getUrlCreateItem());
            curl_setopt($curl, CURLOPT_POST, true);
            curl_setopt($curl, CURLOPT_POSTFIELDS, $urlEncoded);
               // var_dump($urlEncoded);die;
            curl_setopt($curl, CURLOPT_TIMEOUT, '30000'); 
            curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
           // var_dump(curl_exec($curl));die;
            $response = curl_exec($curl); 
            $httpCode = curl_getinfo($curl, CURLINFO_HTTP_CODE); 
         //   var_dump(curl_setopt($curl, CURLOPT_URL, $this->getUrlCreateItem()));die;
            if ($response === false) {
                throw new \Exception(curl_error($curl), curl_errno($curl));
            }
            if (substr($httpCode, 0 ,1) === '4'){
                throw new \Exception('Error HTTP '.$httpCode.' - '.self::HTTP[$httpCode].'. Não foi possivel estalecer conexão com Jenkins');
            }
            curl_close($curl);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function configuration()
    {
        try {
		
			self::validateFieldsRequiredCreate();
			 
            if ($this->getSubmit() === null)
                $this->setSubmit('Salvar');

            self::showMessageFiedsRequired(array('Name' => $this->getName()));

            $fieldsRequest = array('name' => array($this->getName()),
                'description' => array($this->getDescription()),
                'ReverseBuildTrigger.threshold' => array('SUCCESS'),
                'hudson-triggers-TimerTrigger' => array('on'),
                '_.spec' => array($this->getPeriod()),
                'touchStoneResultCondition' => array('SUCCESS'),
                'command' => array($this->getMethod()),
                'core:apply' => array(''),
                'json' => array('{"name": "' . $this->getName() . '",
                            "description": "' . $this->getDescription() . '",
                            "logrotate": false,
                            "": "0",
                            "buildDiscarder":
                                {"daysToKeepStr": "",
                                 "numToKeepStr": "",
                                 "artifactDaysToKeepStr": "",
                                 "artifactNumToKeepStr": "",
                                 "stapler-class": "hudson.tasks.LogRotator",
                                 "$class": "hudson.tasks.LogRotator"
                                },
                            "properties":
                                {"stapler-class-bag": "true",
                                 "hudson-model-ParametersDefinitionProperty": {}
                                },
                            "disable": false,
                            "concurrentBuild": false,
                            "hasCustomQuietPeriod": false,
                            "quiet_period": "5",
                            "hasCustomScmCheckoutRetryCount": false,
                            "scmCheckoutRetryCount": "0",
                            "blockBuildWhenUpstreamBuilding": false,
                            "blockBuildWhenDownstreamBuilding": false,
                            "displayNameOrNull": "",
                            "scm": {"value": "0"},
                            "hudson-triggers-TimerTrigger": {"spec": "' . $this->getPeriod() . '"},
                            "executionStrategy":
                                {"runSequentially": false,
                                 "hasTouchStoneCombinationFilter": false,
                                 "touchStoneCombinationFilter": "",
                                 "touchStoneResultCondition": "SUCCESS"
                                },
                            "builder":
                                {"command": "' . addslashes($this->getMethod()) . '",
                                 "stapler-class": "hudson.tasks.BatchFile",
                                 "$class": "hudson.tasks.BatchFile"
                                },
                            "core:apply": ""}'
                ),
                'Submit' => array($this->getSubmit())
            );
            $encodedUrl = self::encodeUrl($fieldsRequest);

            $curl = curl_init();
            
            curl_setopt($curl, CURLOPT_URL, $this->getUrlConfig());
            curl_setopt($curl, CURLOPT_POST, true);
            curl_setopt($curl, CURLOPT_POSTFIELDS, $encodedUrl);
            curl_setopt($curl, CURLOPT_TIMEOUT, '30000'); 
            curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);

            $content = curl_exec($curl);
            $httpCode = curl_getinfo($curl, CURLINFO_HTTP_CODE); 
            
            if ($content === false) {
                throw new \Exception(curl_error($curl), curl_errno($curl));
            }
            if (substr($httpCode, 0 ,1) === '4'){
                throw new \Exception('Error HTTP '.$httpCode.' - '.self::HTTP[$httpCode].'. Não foi possivel estalecer conexão com Jenkins');
            }
            curl_close($curl);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function deleteJob()
    {
        $curl = curl_init();
        curl_setopt($curl, CURLOPT_URL, $this->getUrlDelete());
        curl_setopt($curl, CURLOPT_POST, true);
        curl_setopt($curl, CURLOPT_TIMEOUT, '30000'); 
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        
        $content = curl_exec($curl);
        $httpCode = curl_getinfo($curl, CURLINFO_HTTP_CODE); 
            
        if ($content === false) {
            throw new \Exception(curl_error($curl), curl_errno($curl));
        }
        if (substr($httpCode, 0 ,1) === '4'){
            throw new \Exception('Error HTTP '.$httpCode.' - '.self::HTTP[$httpCode].'. Não foi possivel estalecer conexão com Jenkins');
        }
        curl_close($curl);
    }
    
    public function createJobLinux($jenkinsPath)
    {
        try {
            $crumb = file_get_contents($jenkinsPath.'crumbIssuer/api/xml?xpath=concat(//crumbRequestField,":",//crumb)');
     
            if ($this->getSubmit() === null)
                $this->setSubmit('OK');

            $fieldsRequest = array('name' => array($this->getName()),
                'mode' => array($this->getType()),
                'from' => array($this->getFrom()),
                'Jenkins-Crumb'=> array(explode(":",$crumb)[1]),
                'crumbRequestField' => array('.crumb'),
                'json' => array('{
                            "name": "' . $this->getName() . '",
                            "mode": "' . $this->getType() . '",
                            "from": "' . $this->getFrom() . '",
                            "Jenkins-Crumb": "'. explode(":",$crumb)[1].'",
                            "crumbRequestField" : ".crumb",
                            "Submit": "' . $this->getSubmit() . '"
                          }'),
                'Submit' => array($this->getSubmit())
            );
                   

            $urlEncoded = self::encodeUrl($fieldsRequest);

            $curl = curl_init();
            curl_setopt($curl, CURLOPT_URL, $this->getUrlCreateItem());
            curl_setopt($curl, CURLOPT_POST, true);
            curl_setopt($curl, CURLOPT_POSTFIELDS, $urlEncoded);
            curl_setopt($curl, CURLOPT_TIMEOUT, '30000'); 
            curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
           // var_dump($urlEncoded);die;
            
            $content = curl_exec($curl);
            $httpCode = curl_getinfo($curl, CURLINFO_HTTP_CODE); 
            
            if ($content === false) {
                throw new \Exception(curl_error($curl), curl_errno($curl));
            }
            if (substr($httpCode, 0 ,1) === '4'){
                throw new \Exception('Error HTTP '.$httpCode.' - '.self::HTTP[$httpCode].'. Não foi possivel estalecer conexão com Jenkins');
            }
            curl_close($curl);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function configurationLinux($jenkinsPath)
    {
        try {
		
			self::validateFieldsRequiredCreate();
			 
            if ($this->getSubmit() === null)
                $this->setSubmit('Salvar');

            self::showMessageFiedsRequired(array('Name' => $this->getName()));

            $crumb = file_get_contents($jenkinsPath.'crumbIssuer/api/xml?xpath=concat(//crumbRequestField,":",//crumb)');
            
            $fieldsRequest = array('name' => array($this->getName()),
                'Jenkins-Crumb' => array(explode(":",$crumb)[1]),
                'crumbRequestField' => array('.crumb'),
                'description' => array($this->getDescription()),
                'ReverseBuildTrigger.threshold' => array('SUCCESS'),
                'hudson-triggers-TimerTrigger' => array('on'),
                '_.spec' => array($this->getPeriod()),
                'touchStoneResultCondition' => array('SUCCESS'),
                'command' => array($this->getMethod()),
                'core:apply' => array(''),
                'json' => array('{"name": "' . $this->getName() . '",
                            "Jenkins-Crumb": "'. explode(":",$crumb)[1].'",
                            "crumbRequestField" : ".crumb",
                            "description": "' . $this->getDescription() . '",
                            "logrotate": false,
                            "": "0",
                            "buildDiscarder":
                                {"daysToKeepStr": "",
                                 "numToKeepStr": "",
                                 "artifactDaysToKeepStr": "",
                                 "artifactNumToKeepStr": "",
                                 "stapler-class": "hudson.tasks.LogRotator",
                                 "$class": "hudson.tasks.LogRotator"
                                },
                            "properties":
                                {"stapler-class-bag": "true",
                                 "hudson-model-ParametersDefinitionProperty": {}
                                },
                            "disable": false,
                            "concurrentBuild": false,
                            "hasCustomQuietPeriod": false,
                            "quiet_period": "5",
                            "hasCustomScmCheckoutRetryCount": false,
                            "scmCheckoutRetryCount": "0",
                            "blockBuildWhenUpstreamBuilding": false,
                            "blockBuildWhenDownstreamBuilding": false,
                            "displayNameOrNull": "",
                            "scm": {"value": "0"},
                            "hudson-triggers-TimerTrigger": {"spec": "' . $this->getPeriod() . '"},
                            "executionStrategy":
                                {"runSequentially": false,
                                 "hasTouchStoneCombinationFilter": false,
                                 "touchStoneCombinationFilter": "",
                                 "touchStoneResultCondition": "SUCCESS"
                                },
                            "BuildTimeoutWrapper": {
                                "timeout": {
                                    "time": 720,
                                    "unit": MINUTES
                                }
                            },
                            "builder":
                                {
                                    "command": "' . addslashes($this->getMethod()) . '",
                                    "stapler-class": "hudson.tasks.Shell",
                                    "$class": "hudson.tasks.Shell"
                                },
                            "core:apply": ""}'
                ),
                'Submit' => array($this->getSubmit())
            );
            $encodedUrl = self::encodeUrl($fieldsRequest);

            $curl = curl_init();
            
            curl_setopt($curl, CURLOPT_URL, $this->getUrlConfig());
            curl_setopt($curl, CURLOPT_POST, true);
            curl_setopt($curl, CURLOPT_POSTFIELDS, $encodedUrl);
            curl_setopt($curl, CURLOPT_TIMEOUT, '30000'); 
            curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
            
            $content = curl_exec($curl);
            $httpCode = curl_getinfo($curl, CURLINFO_HTTP_CODE); 
            
            if ($content === false) {
                throw new \Exception(curl_error($curl), curl_errno($curl));
            }
            if (substr($httpCode, 0 ,1) === '4'){
                throw new \Exception('Error HTTP '.$httpCode.' - '.self::HTTP[$httpCode].'. Não foi possivel estalecer conexão com Jenkins');
            }
            curl_close($curl);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function deleteJobLinux($jenkinsPath)
    {
        
        $crumb = file_get_contents($jenkinsPath.'crumbIssuer/api/xml?xpath=concat(//crumbRequestField,":",//crumb)');
        
        $fieldsRequest = array('Jenkins-Crumb'=> array(explode(":",$crumb)[1]),
                'crumbRequestField' => array('.crumb'),
                'json' => array('{
                            "Jenkins-Crumb": "'. explode(":",$crumb)[1].'",
                            "crumbRequestField" : ".crumb"
                          }'),
                'Submit' => array($this->getSubmit())
        );

        $encodedUrl = self::encodeUrl($fieldsRequest);

        $curl = curl_init();
        curl_setopt($curl, CURLOPT_URL, $this->getUrlDelete());
        curl_setopt($curl, CURLOPT_POST, true);
        curl_setopt($curl, CURLOPT_POSTFIELDS, $encodedUrl);
        curl_setopt($curl, CURLOPT_TIMEOUT, '30000'); 
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        
        $content = curl_exec($curl);
        $httpCode = curl_getinfo($curl, CURLINFO_HTTP_CODE); 
        
        if ($content === false) {
            throw new \Exception(curl_error($curl), curl_errno($curl));
        }
        if (substr($httpCode, 0 ,1) === '4'){
            throw new \Exception('Error HTTP '.$httpCode.' - '.self::HTTP[$httpCode].'. Não foi possivel estalecer conexão com Jenkins');
        }
        curl_close($curl);
    }

    public static function encodeUrl($fieldsRequest)
    {
        $urlEncoded = null;
        foreach ($fieldsRequest as $key => $fields) {
            $key = urlencode(trim($key));
            foreach ($fields as $value) {
                $value = urlencode(trim($value));
                $urlEncoded .= $key . '=' . $value . '&';
            }
        }
        if (!empty($urlEncoded))
            $urlEncoded = rtrim($urlEncoded, '&');

        return $urlEncoded;
    }

    public static function revertDirectory($directory)
    {
        return str_replace( '\\', '/', $directory);
    }

    public function validateFieldsRequiredCreate()
    {
        $fieldsRequired = array (
            'Url Jenkins' => $this->getUrlJenkins(),
            'Url Create Item' => $this->getUrlCreateItem(),
            'Name' => $this->getName(),
            'Type' => $this->getType(),
        );

        self::showMessageFiedsRequired($fieldsRequired);

        if ($fieldsRequired['Type'] == self::TYPE_JOB_COPY && $this->getFrom() == null)
            throw new \Exception('From is required.');
        elseif ($fieldsRequired['Type'] != self::TYPE_JOB_COPY)
            $this->setFrom(null);
    }

    public static function showMessageFiedsRequired($fieldsRequired)
    {
        foreach ($fieldsRequired as $key => $field) {
            if (empty($field))
                throw new \Exception($key . ' is required.');
        }
    }

    public static function formatDateToExecute($dateExec, $periodicidade, $dayWeek = '*')
    {
        $dateExec = trim($dateExec);
		
        list ($hour, $min, $day, $month) = array('*', '*', '*', '*');
        
		if (!empty($dateExec) && strlen($dateExec) > 10) {
            list ($date, $time) = explode(" ", $dateExec);
            list ($day, $month) = explode("/", $date);
            list ($hour, $min) = explode(":", $time);
        } elseif (strlen($dateExec) == 10)
            list ($day, $month) = explode("/", $dateExec);
			
		if($periodicidade != 0){
		    $month = '1-12';
		}	
			
        $dateExec = implode(" ",array("H", $hour, $day, $month, $dayWeek) );
        return $dateExec;
    }
}
