<?php

namespace Teknisa\FIS\Modules\Apuracoes\Controllers;

use Doctrine\ORM\EntityManager;
use Teknisa\FIS\Modules\Apuracoes\Services\Fis41000ApuracaoAutomaticaService;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\ParameterBag;

class Fis41000ApuracaoAutomaticaController extends \Teknisa\FIS\Controllers\TeknisaCrud {
    
    protected $crudService; 
    protected $dataSourceName;
    protected $dataSourceNameToSave  = false;
    /** @var ParameterBag */
    protected $parameterBag;
    /** @var string[] */
    protected $parameterBagColumns = array();

    public function __construct($crudService, ParameterBag $parameterBag, EntityManager $entityManager, Fis41000ApuracaoAutomaticaService $serviceApuracaoAutomatica) {
        $this->entityManager            = $entityManager;
        $this->serviceApuracaoAutomatica = $serviceApuracaoAutomatica;
        parent::__construct($crudService, $parameterBag);
    }

    public function salvarApuracAutomatica(DTO\Request\Row $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            
            $this->serviceApuracaoAutomatica->salvarApuracAutomatica($row);
            
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }   
    
    
    public function execApuracaoAuto(DTO\Request $request, DTO\Response $response) {
       try {
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();
            
            $row = $request->getParameters();
            $_SESSION['_sf2_attributes']['NRORG'] = $row['NRORG'];
            $_SESSION['_sf2_attributes']['ORGANIZATION_ID'] = $row['NRORG'];
            
            $this->serviceApuracaoAutomatica->loop($row);
            
            $this->entityManager->commit();

        } catch(\Exception $e) {
            var_dump($e->getMessage());
            $this->entityManager->rollback();
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
     
    
    public function execVerificaApuracaoAuto(DTO\Request $request, DTO\Response $response) {
        try {
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();
            
            $row = $request->getParameters();
            $row['NRORG'] = 1;
            $_SESSION['_sf2_attributes']['NRORG'] = $row['NRORG'];
            $_SESSION['_sf2_attributes']['ORGANIZATION_ID'] = $row['NRORG'];
            
            $this->serviceApuracaoAutomatica->execApuracaoAuto($row, true);
            
            $this->entityManager->commit();

        } catch(\Exception $e) {
            var_dump($e->getMessage());
            $this->entityManager->rollback();
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

    public function deleteArquivo(DTO\Request $request, DTO\Response $response) {
        try {
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();
            
            foreach($request->getDataSet()->getRows() as $row){
                $this->serviceApuracaoAutomatica->deleteArquivos($row);
            }
            
            $this->entityManager->commit();

        } catch(\Exception $e) {
            $this->entityManager->rollback();
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
}