<?php

namespace Teknisa\FIS\Modules\Apuracoes\Factories;

use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;


class Fis00100ApuracaoDeImpostoFactory{
    protected $connection;
    protected $entityManager;

    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    //GERA_INFADIC_GIA_RS(:P_NRSEQUMAPAPU, :P_CDLIVROMAG, :P_NREMPREGADOS, :P_VRFOLHA, :P_INSCRCENTRAL, :P_ATODECLARA);
    public function geraGiaRs($params) {
        $procedure = new StoredProcedure($this->entityManager->getConnection(), 'GERA_INFADIC_GIA_RS');

        $procedure->addParam(new Param('P_NRSEQUMAPAPU',    Param::PARAM_INPUT, $params["NRSEQUMAPAPU"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDLIVROMAG',      Param::PARAM_INPUT, $params["CDLIVROMAG"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NREMPREGADOS',    Param::PARAM_INPUT, $params["NREMPREGADOS"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_VRFOLHA',         Param::PARAM_INPUT, $params["VRFOLHA"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_INSCRCENTRAL',    Param::PARAM_INPUT, $params["INSCRCENTRAL"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_ATODECLARA',      Param::PARAM_INPUT, isset($params["ATODECLARA"]) ? $params["ATODECLARA"] : null , Param::PARAM_TYPE_STR));
        $procedure->execute();
    }
    
    public function gerarGuiaIcmsSt($params) {
        $procedure = new StoredProcedure($this->entityManager->getConnection(), 'GERA_GUIA_ICMS_ST');

        $procedure->addParam(new Param('P_NRSEQUMAPAPU', Param::PARAM_INPUT, $params["NRSEQUMAPAPU"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDTIPOAPURA', Param::PARAM_INPUT, 'M', Param::PARAM_TYPE_STR));
        $procedure->execute();
    }
    
    public function proceduraDeletarMapaGeral($params) {
        $procedure = new StoredProcedure($this->entityManager->getConnection(), 'DELETA_MAPA');

        $procedure->addParam(new Param('P_NRSEQUMAPAPU', Param::PARAM_INPUT, $params["NRSEQUMAPAPU"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_BOBLOQ', Param::PARAM_INPUT, 'N', Param::PARAM_TYPE_STR));
        $procedure->execute();
    }
    
    public function apuraMapa($params) {
        $procedure = new StoredProcedure($this->entityManager->getConnection(), 'APURA_IMPOSTOS_GERAIS');
     //   var_dump($params);die;
        $procedure->addParam(new Param('P_CDIMPOSTO', Param::PARAM_INPUT, $params["CDIMPOSTO"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDEMPRESA', Param::PARAM_INPUT, $params["CDEMPRESA"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDINSCRICAO', Param::PARAM_INPUT, $params["CDINSCRICAO"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRSEQUMAPAPU', Param::PARAM_INPUT, $params["NRSEQUMAPAPU"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTINICIAL', Param::PARAM_INPUT, $params["DTINICIAL"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTFINAL', Param::PARAM_INPUT, $params["DTFINAL"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_BOBLOQ', Param::PARAM_INPUT, $params["BOBLOQ"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CHAMADAPROC', Param::PARAM_INPUT, $params["CHAMADAPROC"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_RETORNO', Param::PARAM_OUTPUT, null, Param::PARAM_TYPE_STR, 12));

        $retornoProcedure = $procedure->execute();
        $codigoRetorno = $retornoProcedure["P_RETORNO"];
       
        return $codigoRetorno;
    }
    
    public function adsDemonsOfic($params) {
        $procedure = new StoredProcedure($this->entityManager->getConnection(), 'DEMONSTRATIVO_OFICIAL');

        $procedure->addParam(new Param('P_CDEMPRESA', Param::PARAM_INPUT, $params["CDEMPRESA"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDTIPODEMO', Param::PARAM_INPUT, isset($params["CDTIPODEMO"]) ? $params["CDTIPODEMO"] : NULL, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DATA', Param::PARAM_INPUT, $params["DTFIMPERIODO"], Param::PARAM_TYPE_STR)); //VER COM RAFA
        $procedure->addParam(new Param('P_PERIODO', Param::PARAM_INPUT, 'M', Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRDRE', Param::PARAM_OUTPUT, null, Param::PARAM_TYPE_STR, 12));

        $retornoProcedure = $procedure->execute();
        $codigoRetorno = $retornoProcedure["P_NRDRE"];
        return $codigoRetorno;
    }
 
    public function apuraIRPJ($params) {
        $procedure = new StoredProcedure($this->entityManager->getConnection(), 'APURA_IRPJ');

        $procedure->addParam(new Param('P_DTINICIAL', Param::PARAM_INPUT, $params["DTINICIAL"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTFINAL', Param::PARAM_INPUT, $params["DTFINAL"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDIMPOSTO', Param::PARAM_INPUT, $params["CDIMPOSTO"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDEMPRESA', Param::PARAM_INPUT, $params["CDEMPRESA"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRSEQUMAPAPU', Param::PARAM_INPUT, $params["NRSEQUMAPAPU"], Param::PARAM_TYPE_STR));
        
        $procedure->addParam(new Param('P_GERBLCT', Param::PARAM_INPUT, $params["GERBLCT"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRDRE', Param::PARAM_INPUT, $params["NRDRE"], Param::PARAM_TYPE_STR));
        
        $retornoProcedure = $procedure->execute();
        
    }
  
    public function apuraCSLL($params) {
        $procedure = new StoredProcedure($this->entityManager->getConnection(), 'APURA_CSLL');

        $procedure->addParam(new Param('P_DTINICIAL', Param::PARAM_INPUT, $params["DTINICIAL"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTFINAL', Param::PARAM_INPUT, $params["DTFINAL"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDIMPOSTO', Param::PARAM_INPUT, $params["CDIMPOSTO"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDEMPRESA', Param::PARAM_INPUT, $params["CDEMPRESA"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRSEQUMAPAPU', Param::PARAM_INPUT, $params["NRSEQUMAPAPU"], Param::PARAM_TYPE_STR));
        
        $procedure->addParam(new Param('P_GERBLCT', Param::PARAM_INPUT, $params["GERBLCT"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRDRE', Param::PARAM_INPUT, $params["NRDRE"], Param::PARAM_TYPE_STR));
        
        $retornoProcedure = $procedure->execute();
        
    }
    
    public function apuraMapaContribuicoes($parametros) {
        $sql = " declare v_P_BOBLOQUEIA boolean := sys.DIUTIL.INT_TO_BOOL(:P_BOBLOQUEIA); begin GERA_APURACAO_CONTRIBUICOES(:P_DTINICIAL, :P_DTFINAL, :P_IDIMPORECUPNFE, :P_CDIMPOSTONFE, :P_NRSEQUMAPAPU, :P_CDEMPRESA, v_P_BOBLOQUEIA); end;";
        $params = array(
            "P_DTINICIAL"       => $parametros['DTINICIAL'],
            "P_DTFINAL"         => $parametros['DTFINAL'],
            "P_IDIMPORECUPNFE"  => $parametros['IDIMPORECUPNFE'],
            "P_CDIMPOSTONFE"    => $parametros['CDIMPOSTONFE'],
            "P_NRSEQUMAPAPU"    => $parametros['NRSEQUMAPAPU'],
            "P_CDEMPRESA"       => $parametros['CDEMPRESA'],
            "P_BOBLOQUEIA"      => $parametros['P_BOBLOQUEIA'],
        );
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function apuraMapaSimples($params) {
        $procedure = new StoredProcedure($this->entityManager->getConnection(), 'APURACAO_SIMPLESNACIONAL');

        $procedure->addParam(new Param('P_NRSEQUMAPAPU', Param::PARAM_INPUT, $params["NRSEQUMAPAPU"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDEMPRESA', Param::PARAM_INPUT, $params["CDEMPRESA"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTINICIAL', Param::PARAM_INPUT, $params["DTINIPERIODO"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTFINAL', Param::PARAM_INPUT, $params["DTFIMPERIODO"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRORG', Param::PARAM_INPUT, $params["NRORG"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_RETORNO', Param::PARAM_OUTPUT, null, Param::PARAM_TYPE_STR, 20));

        $retornoProcedure = $procedure->execute();
        $codigoRetorno = $retornoProcedure["P_RETORNO"];
        return $codigoRetorno;
    }

    public function calculaInss($params) {
        $sql = "UPDATE MAPAAPURAC
                   SET VRTTBACALDEB = :P_VRBCFOLHA,
                       VRTTCTBLDEB  = :P_VRAPURFOLHA,
                       VRCOMPENSA   = CALCULA_COMPENSACOES(:P_CDEMPRESA, :P_CDIMPOSTONFE, :P_NRSEQUMAPAPU, :P_DTINICIAL, :P_DTFINAL, :P_IDCUMUPISCOFIL)
                WHERE NRSEQUMAPAPU = :P_NRSEQUMAPAPU";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function calculaTotalInss($params) {
        $sql = " UPDATE MAPAAPURAC
                    SET VRTOTAIMPOS = CASE WHEN (VRTTCTBLDEB - VRCOMPENSA) > 0 THEN (VRTTCTBLDEB - VRCOMPENSA) ELSE 0 END
                WHERE NRSEQUMAPAPU = :P_NRSEQUMAPAPU";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function atualizaNotasFiscaisMapaApuracao($params) {
        $sql = "UPDATE NOTAFISCAL
                    SET NRSEQUMAPAPUSN = NULL
                WHERE NRSEQUMAPAPUSN = :NRSEQUMAPAPU
                AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function atualizaNotasFiscaisGerais($params) {
        $sql = "UPDATE IMPOSTONF
                    SET NRSEQUMAPAPU = NULL,
                    DTREFMAPAPU = DECODE(:DTREFMAPAPU,'S',DTREFMAPAPU,NULL)
                WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU
                AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function atualizaImpbaixarec($params) {
        $sql = "UPDATE IMPBAIXAREC
                    SET NRSEQUMAPAPU = NULL,
                    DTREFMAPAPU = DECODE(:DTREFMAPAPU,'S',DTREFMAPAPU,NULL)
                WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU
                AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function atualizaItemvenoutimpos($params) {
        $sql = "UPDATE ITEMVENOUTIMPOS
                    SET NRSEQUMAPAPU = NULL,
                    DTREFMAPAPU = DECODE(:DTREFMAPAPU,'S',DTREFMAPAPU,NULL)
                WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU
                AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function atualizaNotasFiscaisCompensacoes($params) {
        $sql = "UPDATE IMPOSTONF
                    SET NRSEQMAPOIMP = NULL,
                    DTREFMAPAPU = DECODE(:DTREFMAPAPU,'S',DTREFMAPAPU,NULL)
                WHERE NRSEQMAPOIMP = :NRSEQUMAPAPU
                AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }    
    
    public function updateValorSubstitutoSolidarioIcmsSt($params) {
        $sql = "UPDATE DETITMAPARECUP
                    SET VRIMPOSTOIT = :VRIMPOSTOIT, 
                    IDSUBSTSOLIDST   = :IDSUBSTSOLIDS
                    
                WHERE NRSEQDETITMAPA = :NRSEQDETITMAPA
                AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }    
    
    public function updateSubstitutoSolidarioIcmsSt($params) {
        $sql = "UPDATE DETITMAPARECUP SET IDSUBSTSOLIDST = :IDSUBSTSOLIDST
                WHERE CDFILIAL = :CDFILIAL
                    AND IDTIPOITMAPR = :IDTIPOITMAPR
                    AND NRSEQUMAPAPU = :NRSEQUMAPAPU
                    AND NRLANCTONF = :NRLANCTONF
                    AND NRSEQITMAPR = :NRSEQITMAPR";;

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    } 
    
    public function deleteTodosItensComposicao($params) {
        $sql = "DELETE FROM  DETITMAPARECUP 
                WHERE CDFILIAL = :CDFILIAL
                    AND IDTIPOITMAPR = :IDTIPOITMAPR
                    AND NRSEQUMAPAPU = :NRSEQUMAPAPU
                    AND NRLANCTONF = :NRLANCTONF
                    AND NRSEQITMAPR = :NRSEQITMAPR";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    } 
    
  
    public function verificaGuiaIcmsSt($params) {
        $sql = "SELECT
                    NRSEQUMAPAPU, M.CDPAIS, P.NMPAIS, SGESTADO, CDRECESUBTRIB, DTVENCSUBTRIB,
                    TO_CHAR(DTVENCSUBTRIB, 'dd/mm/yyyy') AS VENCIMENTO, VRCREDITONORMAL, VRDEBITONORMAL,
                    VRCREDANTERIOR, VROUTROSDEBITOS, VROUTROSCREDITOS, VRIMPARECOLHER, VRSALDOCREDOR,
                    VRDEVMAPA, VRRESSAMAPA
                FROM
                    MAPAAPURESTADO M, PAIS P
                WHERE
                    M.NRSEQUMAPAPU = :P_NRSEQUMAPAPU AND
                    M.CDPAIS       = P.CDPAIS
                ORDER BY
                    P.NMPAIS, SGESTADO";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function maiorCodigoGuiasComplementares($params) {
        $sql = "SELECT NVL(MAX(NRSEQGUIACOMPL),0) AS NRSEQGUIACOMPL
                    FROM GUIACOMPLMAPA
                    WHERE   NRSEQUMAPAPU   = :NRSEQUMAPAPU
                        AND NRORG          = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function maiorCodigoGuiasComplementaresContrib($params) {
        $sql = "SELECT NVL(MAX(NRSEQGUIACOMPL),0) AS NRSEQGUIACOMPL
                    FROM GUIACOMPAPUCONTR
                    WHERE   NRSEQUMAPAPU   = :NRSEQUMAPAPU
                        AND NRORG          = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function buscaMapaReferenteContribuicoes ($params){
        $sql = "SELECT *
                FROM MAPAAPURAC
                WHERE CDIMPOSTO          = :CDIMPOSTO
                        AND CDEMPRESA    = :CDEMPRESA
                        AND DTINIPERIODO = :DTINIPERIODO
                        AND DTFIMPERIODO = :DTFIMPERIODO";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function getInformacoesAdiconaisMesAnterior($params){
        $sql = "SELECT NRSEQINFADIC, CDINFADICMAPA, DSINFADICMAPA, NVL((SELECT VRINFADICMAPA FROM INFADICMAPA N WHERE I.NRSEQUMAPAPU = N.NRSEQUMAPAPU AND REPLACE(UPPER(I.DSINFADICMAPA),'INICIAL') = REPLACE(UPPER(N.DSINFADICMAPA),'FINAL') AND INSTR(UPPER (I.DSINFADICMAPA),'INICIAL') > 0),0) AS VRINFADICMAPA FROM INFADICMAPA I WHERE NRSEQUMAPAPU = (SELECT NVL(MAX(NRSEQUMAPAPU),0) FROM MAPAAPURAC WHERE NRSEQUMAPAPU < :P_NRSEQUMAPAPU AND CDEMPRESA = :P_CDEMPRESA AND ((CDINSCESTA = :P_CDINSCESTA) OR (CDINSCESTA IS NULL AND :P_CDINSCESTA IS NULL)) AND CDIMPOSTO = :P_CDIMPOSTO )";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function buscaParcelasAtivo ($params){
        $sql = "SELECT PL.CDFILIAL, PL.NRLANCTONF, PL.NRSEQITPROD, TO_NUMBER(PL.NRPARCATIV) AS ORDPARCELAS, PL.NRPARCATIV, PL.IDTRANSATIV, PL.NRSEQUMAPAPU, PL.VRPARCATIV FROM NOTAFISCAL NF, ITEMPRODUTO IT, PARCLANCATIV PL WHERE NF.CDEMPRESA = :P_EMPRESA AND(:P_INSCRICAO IS NULL OR NF.CDINSCESTA = :P_INSCRICAO) AND NF.IDENTRSAIDOP = 'E' AND NF.CDFILIAL = IT.CDFILIAL AND NF.NRLANCTONF = IT.NRLANCTONF AND IT.QTPARCATIV > 0 AND IT.CDFILIAL = PL.CDFILIAL AND IT.NRLANCTONF = PL.NRLANCTONF AND IT.NRSEQITPROD = PL.NRSEQITPROD AND(PL.IDTRANSATIV IS NULL OR PL.IDTRANSATIV = 'N') AND ((ADD_MONTHS(NF.DTENTRSAID, TO_NUMBER(PL.NRPARCATIV) - 1)) BETWEEN :P_DTINICIAL AND :P_DTFINAL) ORDER BY PL.CDFILIAL, PL.NRLANCTONF, PL.NRSEQITPROD, ORDPARCELAS";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function buscaDataParametroFiscal($params) {
        $sql = "SELECT DTININFFORPER FROM PARAMFISCAL WHERE NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        return $std->fetch()["DTININFFORPER"];
    }

    public function buscaMapaAnterior($params) {
        $sql = "SELECT * FROM MAPAAPURAC WHERE DTINIPERIODO = (SELECT MAX(DTINIPERIODO) FROM (SELECT M.* FROM MAPAAPURAC M WHERE NRORG = :NRORG AND CDEMPRESA = :CDEMPRESA AND CDIMPOSTO = :CDIMPOSTO AND (:IDTIPOAPURA <> 'E' OR CDINSCESTA = :CDINSCESTA) AND (:IDTIPOAPURA <> 'M' OR CDINSCMUNI = :CDINSCMUNI) AND DTINIPERIODO < :DTINIPERIODO) ) AND NRORG = :NRORG AND CDEMPRESA = :CDEMPRESA AND CDIMPOSTO = :CDIMPOSTO AND (:IDTIPOAPURA <> 'E' OR CDINSCESTA = :CDINSCESTA) AND (:IDTIPOAPURA <> 'M' OR CDINSCMUNI = :CDINSCMUNI)";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }

    public function buscaMapaAnteriorSimples($params) {
        $sql = "SELECT *
                    FROM MAPAAPURACSN
                    WHERE DTINIPERIODO =
                        (
                        SELECT MAX(DTINIPERIODO)
                            FROM
                                (SELECT M.*
                                FROM MAPAAPURACSN M
                                WHERE
                                    NRORG      = :NRORG
                                    AND CDEMPRESA    = :CDEMPRESA
                                    AND DTINIPERIODO < :DTINIPERIODO
                                )
                        )
                    AND NRORG     = :NRORG
                    AND CDEMPRESA = :CDEMPRESA";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }

    public function buscaMapaPosterior($params) {
        $sql = "SELECT * FROM MAPAAPURAC WHERE DTINIPERIODO = (SELECT MIN(DTINIPERIODO) FROM (SELECT M.* FROM MAPAAPURAC M WHERE NRORG = :NRORG AND CDEMPRESA = :CDEMPRESA AND CDIMPOSTO = :CDIMPOSTO AND (:IDTIPOAPURA <> 'E' OR CDINSCESTA = :CDINSCESTA) AND (:IDTIPOAPURA <> 'M' OR CDINSCMUNI = :CDINSCMUNI) AND DTINIPERIODO > :DTINIPERIODO) ) AND NRORG = :NRORG AND CDEMPRESA = :CDEMPRESA AND CDIMPOSTO = :CDIMPOSTO AND (:IDTIPOAPURA <> 'E' OR CDINSCESTA = :CDINSCESTA) AND (:IDTIPOAPURA <> 'M' OR CDINSCMUNI = :CDINSCMUNI)";

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        return $std->fetch();
    }

    public function buscaMapaPosteriorSimples($params) {
        $sql = "SELECT *
                    FROM MAPAAPURACSN
                    WHERE DTINIPERIODO =
                      (SELECT MIN(DTINIPERIODO)
                      FROM
                        (SELECT M.*
                        FROM MAPAAPURACSN M
                        WHERE NRORG      = :NRORG
                        AND CDEMPRESA    = :CDEMPRESA
                        AND DTINIPERIODO > :DTINIPERIODO
                        )
                      )
                    AND NRORG     = :NRORG
                    AND CDEMPRESA = :CDEMPRESA";

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        return $std->fetch();
    }

    public function buscaUltimoMapa($params) {
        $sql = "SELECT * FROM MAPAAPURAC WHERE DTINIPERIODO =(SELECT MAX(DTINIPERIODO) FROM MAPAAPURAC M WHERE NRORG = :NRORG AND CDEMPRESA = :CDEMPRESA AND CDIMPOSTO = :CDIMPOSTO AND (:IDTIPOAPURA <> 'E' OR CDINSCESTA = :CDINSCESTA) AND (:IDTIPOAPURA <> 'M' OR CDINSCMUNI = :CDINSCMUNI)) AND NRORG = :NRORG AND CDEMPRESA = :CDEMPRESA AND CDIMPOSTO = :CDIMPOSTO AND (:IDTIPOAPURA <> 'E' OR CDINSCESTA = :CDINSCESTA) AND (:IDTIPOAPURA <> 'M' OR CDINSCMUNI = :CDINSCMUNI)";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }

    public function buscaUltimoMapaSimples($params) {
        $sql = "SELECT *
            FROM MAPAAPURACSN
            WHERE DTINIPERIODO =
              (SELECT MAX(DTINIPERIODO)
              FROM
                (SELECT M.*
                FROM MAPAAPURACSN M
                WHERE NRORG      = :NRORG
                AND CDEMPRESA    = :CDEMPRESA
                )
              )
            AND NRORG     = :NRORG
            AND CDEMPRESA = :CDEMPRESA";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }

    public function buscaSequencialItdetapucontr($params) {
        $sql = "SELECT NVL (MAX(NRSEQITDETAPU),0)  +1 AS NRSEQITDETAPU
                FROM ITDETAPUCONTR
                WHERE NRSEQUMAPAPU = :P_NRSEQUMAPAPU
                    AND IDTIPODETAPU = 'CA'";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }

    public function deleteDetitmaparecup($params) {
        $sql = "DELETE FROM DETITMAPARECUP
                WHERE NRSEQDETITMAPA = :NRSEQDETITMAPA 
                    AND NRORG        = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function deleteItensComposicaoNotaFiscal($params) {
        $sql = "DELETE FROM DETITMAPARECUP
                WHERE   NRSEQUMAPAPU = :NRSEQUMAPAPU
                    AND NRSEQITMAPR  = :NRSEQITMAPR
                    AND CDFILIAL     = :CDFILIAL
                    AND NRLANCTONF   = :NRLANCTONF
                    AND IDTIPOITMAPR = :IDTIPOITMAPR
                    AND NRORG        = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function deleteInfadicmapa($params) {
        $sql = "DELETE FROM INFADICMAPA
                WHERE NRSEQUMAPAPU   = :NRSEQUMAPAPU
                    AND NRORG = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function deleteItdetapucontr($params) {
        $sql = "DELETE FROM ITDETAPUCONTR
                WHERE NRSEQUMAPAPU   = :P_NRSEQUMAPAPU
                    AND IDTIPODETAPU = 'CA'
                    AND DSITEMDETAPU = 'CRÉDITO DE PERÍODO ANTERIOR'";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function deletaDetalheapur($params) {
        $sql = "DELETE FROM DETAPURACONTR
                    WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU
                    AND NRORG = :NRORG"
                    ;

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function deletaDetalheapursn($params) {
        $sql = "DELETE FROM DETALHEAPURSN
                    WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU
                    AND NRORG = :NRORG"
                    ;

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function deletaItdetalheapur($params) {
        $sql = "DELETE FROM ITDETAPUCONTR
                    WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU
                    AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function deletaLucropresumido($params) {
        $sql = "DELETE FROM LUCROPRESUMIDO
                    WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU
                    AND CDIMPOSTO      = :CDIMPOSTO
                    AND CDEMPRESA      = :CDEMPRESA
                    AND NRORG          = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function deletaItdetapubalctirpj($params) {
        $sql = "DELETE FROM ITDETAPUBALCTIRPJ
                    WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU
                    AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function deletaBalctredsuspirpj($params) {
        $sql = "DELETE FROM BALCTREDSUSPIRPJ
                    WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU
                    AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function deletaRecebrutaliqmapa($params) {
        $sql = "DELETE FROM RECEBRUTALIQMAPA
                    WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU
                    AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function deletaMapaapuimpofed($params) {
        $sql = "DELETE FROM MAPAAPUIMPOFED
                    WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU
                    AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function deletaItdetalheapursn($params) {
        $sql = "DELETE FROM ITDETALHEAPURSN
                    WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU
                    AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function deletaMapaapurac($params) {
        $sql = "DELETE FROM MAPAAPURAC
                    WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU
                    AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function deletaMapaapuracsn($params) {
        $sql = "DELETE FROM MAPAAPURACSN
                    WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU
                    AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function deletaGuiacomplmapa($params) {
        $sql = "DELETE FROM GUIACOMPLMAPA
                    WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU
                    AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function deletaAjustmapaapursg($params) {
        $sql = "DELETE FROM AJUSTMAPAAPURSG
                    WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU
                    AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function deletaDetaufmapaest($params) {
        $sql = "DELETE FROM DETAUFMAPAEST
                    WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU
                    AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function deletaGuiacompapucontr($params) {
        $sql = "DELETE FROM GUIACOMPAPUCONTR
                    WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU
                    AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function deletaAjusteapurcontr($params) {
        $sql = "DELETE FROM AJUSTEAPURCONTR
                    WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU
                    AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function deletaMapaapurestado($params) {
        $sql = "DELETE FROM MAPAAPURESTADO
                    WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU
                    AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function deletaErronfprevalid($params) {
        $sql = "DELETE FROM ERRONFPREVALID
                    WHERE CDFILIAL||NRLANCTONF IN (SELECT CDFILIAL||NRLANCTONF
                    FROM NFPREVALIDFIS
                    WHERE NRSEQUMAPAPUNFP = :NRSEQUMAPAPU
                    AND NRORG = :NRORG)";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function deletaNfprevalidfis($params) {
        $sql = "DELETE FROM NFPREVALIDFIS
                    WHERE NRSEQUMAPAPUNFP = :NRSEQUMAPAPU
                    AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function deleteDemoctbtemp() {
        $sql = "DELETE FROM DEMOCTBTEMP";

        $std = $this->connection->prepare($sql);
        $std->execute();
    }
    
    public function adqAliqIRPJCSLL($params) {
        $sql = "SELECT DISTINCT CDTIPODEMO
                    FROM
                 (SELECT I.CDTIPODEMO
                   FROM RECDESPIRPJ R, INFCTBIRPJ I
                  WHERE R.NRSEQRECDESPIRPJ = I.NRSEQPARAMAPU
                    AND R.CDEMPRESA = :P_CDEMPRESA
                 UNION ALL
                 SELECT I.CDTIPODEMO
                   FROM INFCTBIRPJ I, PARAMAPUIRPJ P
                  WHERE I.NRSEQPARAMAPU = P.NRSEQPARAMAPU
                    AND P.CDEMPRESA = :P_CDEMPRESA
                    AND P.IDIMPOSTO = DECODE(:P_CDIMPOSTO,'25','I','C'))";

        $statement = $this->connection->prepare($sql);
        $statement->execute($params);

        return $statement->fetch();
    }
    
    public function getItemComposicao($params) {
        $sql = "SELECT NRSEQDETITMAPA FROM DETITMAPARECUP WHERE NRSEQUMAPAPU = :P_NRSEQUMAPAPU AND IDTIPOITMAPR = :P_IDTIPOITMAPR AND NRSEQITMAPR = :P_NRSEQITMAPR AND CDFILIAL = :P_CDFILIAL AND NRLANCTONF = :P_NRLANCTONF AND NRSEQITPROD = :P_NRSEQITPROD AND CDIMPOSTO = :P_CDIMPOSTO AND NRITPROIMPOS = :P_NRITPROIMPOS";

        $statement = $this->connection->prepare($sql);
        $statement->execute($params);

        return $statement->fetchAll();
    }
    
    public function getItensComposicaoNotaFiscal($params) {
        $sql = "SELECT II.NRORG, PR.CDARVPROD, PR.NMPRODUTO, SUM(II.VRCONTITIMP) AS VRCONTABIL, SUM(II.VRBASECALCIT) AS VRBASECALC, SUM(ROUND(II.VRIMPOSTOIT,2)) AS VRIMPOSTO, II.CDFISCOPERIT, :P_NRSEQUMAPAPU AS NRSEQUMAPAPU, :P_NRSEQITMAPR AS NRSEQITMAPR, :P_IDTIPOITMAPR AS IDTIPOITMAPR, II.CDFILIAL, II.NRLANCTONF, II.NRSEQITPROD, II.CDIMPOSTO, II.NRITPROIMPOS, DT.NRSEQDETITMAPA, DECODE(II.NRITPROIMPOS,'1','Normal','Dif. Alíquota') AS TIPO_IMP FROM ITEMPROIMPOS II, IMPOSTO IM, ITEMPRODUTO IP, PRODUTO PR,(SELECT NRSEQDETITMAPA, CDFILIAL, NRLANCTONF, NRSEQITPROD, CDIMPOSTO, NRITPROIMPOS FROM DETITMAPARECUP WHERE NRSEQUMAPAPU = :P_NRSEQUMAPAPU AND NRSEQITMAPR = :P_NRSEQITMAPR AND IDTIPOITMAPR = :P_IDTIPOITMAPR) DT WHERE II.CDFILIAL = :P_CDFILIAL AND II.NRLANCTONF = :P_NRLANCTONF AND ((II.NRITPROIMPOS = '1' AND II.CDFISCALIT = '1') OR (II.NRITPROIMPOS = '3')) AND II.VRIMPOSTOIT > 0 AND II.CDIMPOSTO = IM.CDIMPOSTO AND IM.CDIMPOSTONFE = :P_CDIMPOSTO AND II.CDFILIAL = IP.CDFILIAL AND II.NRLANCTONF = IP.NRLANCTONF AND II.NRSEQITPROD = IP.NRSEQITPROD AND IP.CDPRODUTO = PR.CDPRODUTO AND II.CDFILIAL = DT.CDFILIAL(+) AND II.NRLANCTONF = DT.NRLANCTONF(+) AND II.NRSEQITPROD = DT.NRSEQITPROD(+) AND II.CDIMPOSTO = DT.CDIMPOSTO(+) AND II.NRITPROIMPOS = DT.NRITPROIMPOS(+) GROUP BY II.NRORG, DT.NRSEQDETITMAPA, PR.CDARVPROD, PR.NMPRODUTO, II.CDFISCOPERIT, II.CDFILIAL, II.NRLANCTONF, II.NRSEQITPROD, II.CDIMPOSTO, II.NRITPROIMPOS ORDER BY PR.CDARVPROD, II.NRSEQITPROD, II.NRITPROIMPOS";

        $statement = $this->connection->prepare($sql);
        $statement->execute($params);

        return $statement->fetchAll();
    } 
    
    public function somaValoresDifalFcp($params) {
        $sql = "SELECT SUM(VRIMPRECDIFAL) AS SOMADIFAL, SUM(VRIMPRECFCP) AS SOMAFCP FROM MAPAAPURESTADONC WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU AND NRORG = :NRORG";

        $statement = $this->connection->prepare($sql);
        $statement->execute($params);

        return $statement->fetch();
    } 
    
    public function getSomaItensComposicaoNotasMarcadas($params) {
        $sql = "SELECT SUM(NVL(ROUND( CASE WHEN DT.IDSUBSTSOLIDST = 'S' THEN DECODE(NVL(DT.VRIMPOSTOIT,0),0,IT.VRIMPOSTOIT,DT.VRIMPOSTOIT) ELSE IT.VRIMPOSTOIT END,2),0)) AS VALOR FROM ITMAPARECUP IM, ITEMPROIMPOS IT, IMPOSTO II, DETITMAPARECUP DT WHERE IM.NRSEQUMAPAPU = :P_NRSEQUMAPAPU AND IM.IDTIPOITMAPR = :P_IDTIPOITMAPR AND IM.NRSEQITMAPR = :P_NRSEQITMAPR AND IT.CDFILIAL = :P_CDFILIAL AND IT.NRLANCTONF = :P_NRLANCTONF AND IT.CDIMPOSTO = II.CDIMPOSTO AND II.CDIMPOSTONFE = DECODE(SUBSTR(IM.CDAJUSTEITMAPA,4,1),'1','80','00') AND IM.NRSEQUMAPAPU = DT.NRSEQUMAPAPU AND IM.IDTIPOITMAPR = DT.IDTIPOITMAPR AND IM.NRSEQITMAPR = DT.NRSEQITMAPR AND IT.CDFILIAL = DT.CDFILIAL AND IT.NRLANCTONF = DT.NRLANCTONF AND IT.NRSEQITPROD = DT.NRSEQITPROD AND IT.NRITPROIMPOS = DT.NRITPROIMPOS AND IT.CDIMPOSTO = DT.CDIMPOSTO AND IT.VRIMPOSTOIT > 0";

        $statement = $this->connection->prepare($sql);
        $statement->execute($params);

        return $statement->fetch();
    }
    
    public function getSomaItensComposicaoTodasNotas($params) {
        $sql = "SELECT NVL(SUM(ROUND(II.VRIMPOSTOIT,2)),0) AS VRIMPOSTO FROM ITEMPROIMPOS II, IMPOSTO IM WHERE II.CDFILIAL = :P_CDFILIAL AND II.NRLANCTONF = :P_NRLANCTONF AND((II.NRITPROIMPOS = '1' AND II.CDFISCALIT = '1') OR (II.NRITPROIMPOS = '3')) AND II.VRIMPOSTOIT > 0 AND II.CDIMPOSTO = IM.CDIMPOSTO AND IM.CDIMPOSTONFE = :P_CDIMPOSTO";

        $statement = $this->connection->prepare($sql);
        $statement->execute($params);

        return $statement->fetch();
    }
    
    public function getCodigoinfadicmapa($params) {
        $sql = "SELECT NVL(MAX (NRSEQINFADIC),0)+1 AS NRSEQINFADIC FROM INFADICMAPA WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU AND NRORG = :NRORG";

        $statement = $this->connection->prepare($sql);
        $statement->execute($params);

        return $statement->fetch();
    }
    
    public function getEstadoInscricao($params) {
        $sql = "SELECT SGESTADO FROM INSCRESTAD WHERE CDINSCESTA = :CDINSCESTA AND CDEMPRESA = :CDEMPRESA";

        $statement = $this->connection->prepare($sql);
        $statement->execute($params);

        return $statement->fetch();
    }
    
    public function getItmaparecup($params) {
        $sql = "SELECT * FROM ITMAPARECUP WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU AND IDTIPOITMAPR = :IDTIPOITMAPR AND NRSEQITMAPR = :NRSEQITMAPR";

        $statement = $this->connection->prepare($sql);
        $statement->execute($params);

        return $statement->fetch();
    }
    
    public function getAjustmapaapursg($params) {
        $sql = "SELECT * FROM AJUSTMAPAAPURSG WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU AND CDPAIS = :CDPAIS AND SGESTADO = :SGESTADO AND NRSEQAJUSAPURSG = :NRSEQAJUSAPURSG AND NRORG = :NRORG AND NRSEQMAPAAPUREST = :NRSEQMAPAAPUREST ";

        $statement = $this->connection->prepare($sql);
        $statement->execute($params);

        return $statement->fetch();
    }
    
    public function getMaparecup($params) {
        $sql = "SELECT * FROM MAPARECUP WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU AND NRORG = :NRORG";

        $statement = $this->connection->prepare($sql);
        $statement->execute($params);

        return $statement->fetch();
    }

    public function getDetapuracontr($params) {
        $sql = "SELECT * FROM DETAPURACONTR WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU AND NRORG = :NRORG";

        $statement = $this->connection->prepare($sql);
        $statement->execute($params);

        return $statement->fetch();
    }

    public function getDtIniApuracao($params) {
        $sql = "SELECT NVL(DTINIPERLANC,DTININFFORPER) AS DTINIPERLANC FROM PARAMFISCAL WHERE NRORG = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch()["DTINIPERLANC"];
    }

    public function getIdbloqmapapu($params) {
        $sql = "SELECT IDBLOQMAPAPU FROM MAPAAPURAC WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU UNION ALL SELECT IDBLOQMAPAPU FROM MAPAAPURACSN WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        return $std->fetch();
    }

    public function getImpostoNfe($params) {
        $sql = "SELECT CDIMPOSTONFE, IDORGARRECADNFE, IDFORMAPURNFE, IDIMPORECUPNFE FROM IMPOSTONFE I WHERE I.NRORG = :NRORG AND I.CDIMPOSTONFE = :CDIMPOSTONFE";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }

    public function getImpostoRelac($params) {
        $sql = "SELECT CDIMPOSTO, IDORGARRECAD, IDFORMAPUR, IDIMPORECUP FROM IMPOSTO I WHERE I.NRORG = :NRORG AND I.CDIMPOSTONFE = :CDIMPOSTONFE";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    public function getImpostoApurac($params) {
        $sql = "SSELECT A.CDIMPOSTONFE, A.CDIMPOSTO, A.SGIMPOSTO, A.CDIMPOSAPUR, A.CDIMPCARGATRIB, A.IDIMPVALIDASPED, A.IDATUCCTBITIMP, A.IDORGARRECAD, A.IDIMPORECUP, A.IDFORMAPUR,      A.VRALIQPRES,     A.VRPERCADICIR, A.VRALIQIMPLCPR,  A.VRLIMADICLCPR,   A.CDTIPOPERFATU FROM IMPOSTO A WHERE A.CDIMPOSTONFE = :P_IMPOSTO ORDER BY A.CDIMPOSTO";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function getItemDetalhamento($params) {
        $sql = "SELECT D.NRSEQUMAPAPU, D.IDTIPODETAPU, D.NRSEQITDETAPU, D.DSITEMDETAPU, D.VRITEMDETAPU, D.CDFILIAL, D.NRLANCTONF, N.NRNOTAFISC, D.VRBASEITEMDETAPU, D.IDORIGDEDUC, D.IDCUMUPISCOFIL FROM NOTAFISCAL N,(SELECT NRSEQUMAPAPU, IDTIPODETAPU, NRSEQITDETAPU, DSITEMDETAPU, VRITEMDETAPU, CDFILIAL, NRLANCTONF, VRBASEITEMDETAPU, IDORIGDEDUC, IDCUMUPISCOFIL FROM ITDETAPUCONTR WHERE (NRSEQUMAPAPU = :NRSEQUMAPAPU) AND (IDTIPODETAPU = :IDTIPODETAPU) AND (NRSEQITDETAPU = :NRSEQITDETAPU) AND (NRORG = :NRORG))D WHERE N.NRLANCTONF(+) = D.NRLANCTONF AND N.CDFILIAL(+) = D.CDFILIAL ORDER BY D.NRSEQITDETAPU";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }

    public function getMapaapurac($params) {
        $sql = "SELECT * FROM MAPAAPURAC WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU AND NRORG = :NRORG";

        $statement = $this->connection->prepare($sql);
        $statement->execute($params);

        return $statement->fetch();
    }
    
    public function getMapaapurestado($params) {
        $sql = "SELECT * FROM MAPAAPURESTADO WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU AND NRORG = :NRORG AND NRSEQMAPAAPUREST = :NRSEQMAPAAPUREST AND CDPAIS = :CDPAIS AND SGESTADO = :SGESTADO ";

        $statement = $this->connection->prepare($sql);
        $statement->execute($params);

        return $statement->fetch();
    }
    
    public function getTodosMapaapurestado($params) {
        $sql = "SELECT * FROM MAPAAPURESTADO WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU AND NRORG = :NRORG";

        $statement = $this->connection->prepare($sql);
        $statement->execute($params);

        return $statement->fetchAll();
    }
    
    public function getMapaapurestadonc($params) {
        $sql = "SELECT * FROM MAPAAPURESTADONC WHERE NRSEQMAPAPURESTNC = :NRSEQMAPAPURESTNC AND NRORG = :NRORG";

        $statement = $this->connection->prepare($sql);
        $statement->execute($params);

        return $statement->fetch();
    }
    
    public function getMaparecupnc($params) {
        $sql = "SELECT * FROM MAPARECUPNC WHERE NRSEQMAPAPURESTNC = :NRSEQMAPAPURESTNC AND NRORG = :NRORG";

        $statement = $this->connection->prepare($sql);
        $statement->execute($params);

        return $statement->fetch();
    }

    public function getMapaDetalhamentoContribuicoes($params) {
        $sql = "SELECT VRTOTAIMPOS, DTVENCGUIA, VRDEBITOSCUM, CDRECECUMU, VRDEBITOSNC, CDRECENCUMU FROM MAPAAPURAC M JOIN DETAPURACONTR D ON M.NRSEQUMAPAPU = D.NRSEQUMAPAPU AND M.NRORG = D.NRORG WHERE M.NRSEQUMAPAPU = :NRSEQUMAPAPU AND M.NRORG = :NRORG";

        $statement = $this->connection->prepare($sql);
        $statement->execute($params);

        return $statement->fetch();
    }

    public function getNextSequencialAjusteContribuicoes($params) {
        $sql = "SELECT (NVL(MAX(NRSEQAJUSTE), 0) + 1) AS NEXTSEQUENCIAL FROM AJUSTEAPURCONTR WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU AND NRORG = :NRORG";

        $statement = $this->connection->prepare($sql);
        $statement->execute($params);

        return $statement->fetch()["NEXTSEQUENCIAL"];
    }

    public function getNotaCompensacaoForaPeriodo($params) {
        $sql = "SELECT N.CDFILIAL, N.NRLANCTONF, N.NRNOTAFISC FROM NOTAFISCAL N, IMPOSTONF I, PARAMFISCAL P, IMPOSTO IM WHERE(N.CDFILIAL = I.CDFILIAL) AND (N.NRLANCTONF = I.NRLANCTONF) AND (N.NRORG = I.NRORG) AND (N.NRORG = :NRORG) AND (N.IDENTRSAIDOP = 'E') AND (N.DTENTRSAID BETWEEN P.DTININFFORPER AND :DTFINFORPER) AND (N.NRORG = P.NRORG) AND (I.NRSEQMAPOIMP = :NRSEQUMAPAPU) AND (I.CDIMPOSTO = IM.CDIMPOSTO) AND (I.NRORG = IM.NRORG) AND (IM.CDIMPOSTONFE IN ('56','66')) AND (IM.IDFORMAPUR = 'C') UNION ALL SELECT N.CDFILIAL, N.NRLANCTONF, N.NRNOTAFISC FROM NOTAFISCAL N, IMPOSTONF I, PARAMFISCAL P, IMPOSTO IM WHERE (N.CDFILIAL = I.CDFILIAL) AND (N.NRLANCTONF = I.NRLANCTONF) AND (N.NRORG = I.NRORG) AND (N.NRORG = :NRORG) AND (N.IDENTRSAIDOP = 'S') AND (N.DTEMISSAO BETWEEN P.DTININFFORPER AND :DTFINFORPER) AND (N.NRORG = P.NRORG) AND (I.NRSEQMAPOIMP = :NRSEQUMAPAPU) AND (I.CDIMPOSTO = IM.CDIMPOSTO) AND (I.NRORG = IM.NRORG) AND (IM.CDIMPOSTONFE IN ('56','66')) AND (IM.IDFORMAPUR = 'C') UNION ALL SELECT N.CDFILIAL, N.NRLANCTONF, N.NRNOTAFISC FROM NOTAFISCAL N, IMPOSTONF I, CONTAPAGAR C, BOLETPAGAR B, BAIXAPAGA BX, PARAMFISCAL P, IMPOSTO IM WHERE (N.CDFILIAL = I.CDFILIAL) AND (N.NRLANCTONF = I.NRLANCTONF) AND (N.NRORG = I.NRORG) AND (N.NRORG = :NRORG) AND (I.CDFILIAL = C.CDFILIAL) AND (I.NRLANCTONF = C.NRLANCTONF) AND (I.NRORG = C.NRORG) AND (C.CDFILIBPAG = B.CDFILIAL) AND (C.NRLANBOLPAG = B.NRLANBOLPAG) AND (C.NRORG = B.NRORG) AND (B.CDFILIBAIPAG = BX.CDFILIAL) AND (B.NRBAIXAPAG = BX.NRBAIXAPAG) AND (B.NRORG = BX.NRORG) AND (N.IDENTRSAIDOP = 'E') AND (BX.DTBAIXAPAG BETWEEN P.DTININFFORPER AND :DTFINFORPER) AND (BX.NRORG = P.NRORG) AND (I.NRSEQMAPOIMP = :NRSEQUMAPAPU) AND (I.CDIMPOSTO = IM.CDIMPOSTO) AND (I.NRORG = IM.NRORG) AND (IM.CDIMPOSTONFE IN ('56','66')) AND (IM.IDFORMAPUR = 'P') UNION ALL SELECT N.CDFILIAL, N.NRLANCTONF, N.NRNOTAFISC FROM NOTAFISCAL N, IMPOSTONF I, CONTARECEBER C, BOLETRECEBER B, BAIXARECEBIDA BX, PARAMFISCAL P, IMPOSTO IM WHERE (N.CDFILIAL = I.CDFILIAL) AND (N.NRLANCTONF = I.NRLANCTONF) AND (N.NRORG = I.NRORG) AND (N.NRORG = :NRORG) AND (I.CDFILIAL = C.CDFILIAL) AND (I.NRLANCTONF = C.NRLANCTONF) AND (I.NRORG = C.NRORG) AND (C.CDFILIBOLREC = B.CDFILIAL) AND (C.NRLANBOLREC = B.NRLANBOLREC) AND (C.NRORG = B.NRORG) AND (B.CDFILIBAIREC = BX.CDFILIAL) AND (B.NRBAIXAREC = BX.NRBAIXAREC) AND (B.NRORG = BX.NRORG) AND (N.IDENTRSAIDOP = 'S') AND (BX.DTBAIXAREC BETWEEN P.DTININFFORPER AND :DTFINFORPER) AND (BX.NRORG = P.NRORG) AND (I.NRSEQMAPOIMP = :NRSEQUMAPAPU) AND (I.CDIMPOSTO = IM.CDIMPOSTO) AND (I.NRORG = IM.NRORG) AND (IM.CDIMPOSTONFE IN ('56','66')) AND (IM.IDFORMAPUR = 'P') UNION ALL SELECT N.CDFILIAL, N.NRLANCTONF, N.NRNOTAFISC FROM NOTAFISCAL N, IMPBAIXAREC I, IMPOSTO IM, PARAMFISCAL P WHERE (N.CDFILIAL = I.CDFILIAL) AND (N.NRLANCTONF = I.NRLANCTONF) AND (N.NRORG = I.NRORG) AND (N.NRORG = :NRORG) AND (I.DTBAIXAREC BETWEEN P.DTININFFORPER AND :DTFINFORPER) AND (I.NRORG = P.NRORG) AND (I.NRSEQMAPOIMP = :NRSEQUMAPAPU) AND (I.CDIMPOSTO = IM.CDIMPOSTO) AND (I.NRORG = IM.NRORG) AND (IM.CDIMPOSTONFE IN ('56','66')) AND (:IDFORMAPURNFE = 'P') UNION ALL SELECT N.CDFILIAL, N.NRLANCTONF, N.NRNOTAFISC FROM NOTAFISCAL N, IMPOSTONF I, PARAMFISCAL P, IMPOSTO IM WHERE (N.CDFILIAL = I.CDFILIAL) AND (N.NRLANCTONF = I.NRLANCTONF) AND (N.NRORG = I.NRORG) AND (N.NRORG = :NRORG) AND (N.DTENTRSAID BETWEEN P.DTININFFORPER AND :DTFINFORPER) AND (N.NRORG = P.NRORG) AND (I.NRSEQMAPOIMP = :NRSEQUMAPAPU) AND (I.CDIMPOSTO = IM.CDIMPOSTO) AND (I.NRORG = IM.NRORG) AND (IM.CDIMPOSTONFE IN ('56','66')) AND (IM.IDFORMAPUR = 'D') UNION ALL SELECT N.CDFILIAL, N.NRLANCTONF, N.NRNOTAFISC FROM NOTAFISCAL N, IMPOSTONF I, PARAMFISCAL P, IMPOSTO IM WHERE (N.CDFILIAL = I.CDFILIAL) AND (N.NRLANCTONF = I.NRLANCTONF) AND (N.NRORG = I.NRORG) AND (N.NRORG = :NRORG) AND (N.DTEMISSAO BETWEEN P.DTININFFORPER AND :DTFINFORPER) AND (N.NRORG = P.NRORG) AND (I.NRSEQMAPOIMP = :NRSEQUMAPAPU) AND (I.CDIMPOSTO = IM.CDIMPOSTO) AND (I.NRORG = IM.NRORG) AND (IM.CDIMPOSTONFE IN ('56','66')) AND (IM.IDFORMAPUR = 'E')";

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        return $std->fetch();
    }
    
    public function getParamfiscal($params) {
        $sql = "SELECT * FROM PARAMFISCAL WHERE NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        return $std->fetch();
    }

    public function getNotaForaPeriodoContribuicoes($params) {
        $sql = "SELECT N.CDFILIAL, N.NRLANCTONF, N.NRNOTAFISC FROM NOTAFISCAL N, IMPOSTONF I, PARAMFISCAL P, IMPOSTO IM WHERE(N.CDFILIAL = I.CDFILIAL) AND(N.NRLANCTONF = I.NRLANCTONF) AND (N.NRORG = I.NRORG) AND (N.NRORG = :NRORG) AND (N.IDENTRSAIDOP = 'E') AND (N.DTENTRSAID BETWEEN P.DTININFFORPER AND :DTFINFORPER) AND (N.NRORG = P.NRORG) AND ((I.NRSEQUMAPAPU = :NRSEQUMAPAPU) OR (I.NRSEQMAPOIMP = :NRSEQUMAPAPU)) AND (:IDFORMAPURNFE = 'C') AND (I.CDIMPOSTO = IM.CDIMPOSTO) AND (I.NRORG = IM.NRORG) AND (IM.CDIMPOSTONFE = :CDIMPOSTONFE) UNION ALL SELECT N.CDFILIAL, N.NRLANCTONF, N.NRNOTAFISC FROM NOTAFISCAL N, IMPOSTONF I, PARAMFISCAL P, IMPOSTO IM WHERE (N.CDFILIAL = I.CDFILIAL) AND (N.NRLANCTONF = I.NRLANCTONF) AND (N.NRORG = I.NRORG) AND (N.NRORG = :NRORG) AND (N.IDENTRSAIDOP = 'S') AND (N.DTEMISSAO BETWEEN P.DTININFFORPER AND :DTFINFORPER) AND (N.NRORG = P.NRORG) AND ((I.NRSEQUMAPAPU = :NRSEQUMAPAPU) OR (I.NRSEQMAPOIMP = :NRSEQUMAPAPU)) AND (:IDFORMAPURNFE = 'C') AND (I.CDIMPOSTO = IM.CDIMPOSTO) AND (I.NRORG = IM.NRORG) AND (IM.CDIMPOSTONFE = :CDIMPOSTONFE) UNION ALL SELECT N.CDFILIAL, N.NRLANCTONF, N.NRNOTAFISC FROM NOTAFISCAL N, IMPOSTONF I, CONTAPAGAR C, BOLETPAGAR B, BAIXAPAGA BX, PARAMFISCAL P, IMPOSTO IM WHERE (N.CDFILIAL = I.CDFILIAL) AND (N.NRLANCTONF = I.NRLANCTONF) AND (N.NRORG = I.NRORG) AND (N.NRORG = :NRORG) AND (I.CDFILIAL = C.CDFILIAL) AND (I.NRLANCTONF = C.NRLANCTONF) AND (I.NRORG = C.NRORG) AND (C.CDFILIBPAG = B.CDFILIAL) AND (C.NRLANBOLPAG = B.NRLANBOLPAG) AND (C.NRORG = B.NRORG) AND (B.CDFILIBAIPAG = BX.CDFILIAL) AND (B.NRBAIXAPAG = BX.NRBAIXAPAG) AND (B.NRORG = BX.NRORG) AND (N.IDENTRSAIDOP = 'E') AND (BX.DTBAIXAPAG BETWEEN P.DTININFFORPER AND :DTFINFORPER) AND (BX.NRORG = P.NRORG) AND ((I.NRSEQUMAPAPU = :NRSEQUMAPAPU) OR (I.NRSEQMAPOIMP = :NRSEQUMAPAPU)) AND (:IDFORMAPURNFE = 'P') AND (I.CDIMPOSTO = IM.CDIMPOSTO) AND (I.NRORG = IM.NRORG) AND (IM.CDIMPOSTONFE = :CDIMPOSTONFE) UNION ALL SELECT N.CDFILIAL, N.NRLANCTONF, N.NRNOTAFISC FROM NOTAFISCAL N, IMPOSTONF I, CONTARECEBER C, BOLETRECEBER B, BAIXARECEBIDA BX, PARAMFISCAL P, IMPOSTO IM WHERE (N.CDFILIAL = I.CDFILIAL) AND (N.NRLANCTONF = I.NRLANCTONF) AND (N.NRORG = I.NRORG) AND (N.NRORG = :NRORG) AND (I.CDFILIAL = C.CDFILIAL) AND (I.NRLANCTONF = C.NRLANCTONF) AND (I.NRORG = C.NRORG) AND (C.CDFILIBOLREC = B.CDFILIAL) AND (C.NRLANBOLREC = B.NRLANBOLREC) AND (C.NRORG = B.NRORG) AND (B.CDFILIBAIREC = BX.CDFILIAL) AND (B.NRBAIXAREC = BX.NRBAIXAREC) AND (B.NRORG = BX.NRORG) AND (N.IDENTRSAIDOP = 'S') AND (BX.DTBAIXAREC BETWEEN P.DTININFFORPER AND :DTFINFORPER) AND (BX.NRORG = P.NRORG) AND ((I.NRSEQUMAPAPU = :NRSEQUMAPAPU) OR (I.NRSEQMAPOIMP = :NRSEQUMAPAPU)) AND (:IDFORMAPURNFE = 'P') AND (I.CDIMPOSTO = IM.CDIMPOSTO) AND (I.NRORG = IM.NRORG) AND (IM.CDIMPOSTONFE = :CDIMPOSTONFE) UNION ALL SELECT N.CDFILIAL, N.NRLANCTONF, N.NRNOTAFISC FROM NOTAFISCAL N, IMPBAIXAREC I, IMPOSTO IM, PARAMFISCAL P WHERE (N.CDFILIAL = I.CDFILIAL) AND (N.NRLANCTONF = I.NRLANCTONF) AND (N.NRORG = I.NRORG) AND (N.NRORG = :NRORG) AND (I.NRORG = P.NRORG) AND (I.DTBAIXAREC BETWEEN P.DTININFFORPER AND :DTFINFORPER) AND (I.NRSEQUMAPAPU = :NRSEQUMAPAPU) AND (I.CDIMPOSTO = IM.CDIMPOSTO) AND (I.NRORG = IM.NRORG) AND (IM.CDIMPOSTONFE = :CDIMPOSTONFE) AND (:IDFORMAPURNFE = 'P') UNION ALL SELECT N.CDFILIAL, N.NRLANCTONF, N.NRNOTAFISC FROM NOTAFISCAL N, IMPOSTONF I, PARAMFISCAL P, IMPOSTO IM WHERE (N.CDFILIAL = I.CDFILIAL) AND (N.NRLANCTONF = I.NRLANCTONF) AND (N.NRORG = I.NRORG) AND (N.NRORG = :NRORG) AND (N.NRORG = P.NRORG) AND (N.DTENTRSAID BETWEEN P.DTININFFORPER AND :DTFINFORPER) AND ((I.NRSEQUMAPAPU = :NRSEQUMAPAPU) OR (I.NRSEQMAPOIMP = :NRSEQUMAPAPU)) AND (:IDFORMAPURNFE = 'D') AND (I.CDIMPOSTO = IM.CDIMPOSTO) AND (I.NRORG = IM.NRORG) AND (IM.CDIMPOSTONFE = :CDIMPOSTONFE) UNION ALL SELECT N.CDFILIAL, N.NRLANCTONF, N.NRNOTAFISC FROM NOTAFISCAL N, IMPOSTONF I, PARAMFISCAL P, IMPOSTO IM WHERE (N.CDFILIAL = I.CDFILIAL) AND (N.NRLANCTONF = I.NRLANCTONF) AND (N.NRORG = I.NRORG) AND (N.NRORG = :NRORG) AND (N.NRORG = P.NRORG) AND (N.DTEMISSAO BETWEEN P.DTININFFORPER AND :DTFINFORPER) AND ((I.NRSEQUMAPAPU = :NRSEQUMAPAPU) OR (I.NRSEQMAPOIMP = :NRSEQUMAPAPU)) AND (:IDFORMAPURNFE = 'E') AND (I.CDIMPOSTO = IM.CDIMPOSTO) AND (I.NRORG = IM.NRORG) AND (IM.CDIMPOSTONFE = :CDIMPOSTONFE)";

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        return $std->fetch();
    }

    public function getNotaPendente($params) {
        $sql = "SELECT DISTINCT I.CDFILIAL, I.NRLANCTONF FROM NOTAFISCAL N, IMPOSTONF I, IMPOSTO IM, PARAMFISCAL P WHERE IDSTATUS = 'P' AND CDEMPRESA = :CDEMPRESA AND CDINSCESTA = :CDINSCESTA AND DECODE(IDENTRSAIDOP, 'E', DTENTRSAID, DTEMISSAO) BETWEEN :DTINICIAL AND :DTFINAL AND IDENTRSAIDOP IN('E', 'S') AND I.CDFILIAL = N.CDFILIAL AND I.NRLANCTONF = N.NRLANCTONF AND I.NRORG = N.NRORG AND I.CDIMPOSTO = IM.CDIMPOSTO AND I.NRORG = IM.NRORG AND :CDIMPOSTO = IM.CDIMPOSTONFE AND P.NRORG = IM.NRORG AND P.IDBLOQNFPENDE = 'S' AND P.NRORG = :NRORG AND IDSTATUSNFE <> 'D' UNION ALL SELECT DISTINCT N.CDFILIAL, N.NRLANCTONF FROM NOTAFISCAL N, IMPOBRIGTPOPER I, IMPOSTO IM, PARAMFISCAL P WHERE DECODE(N.IDENTRSAIDOP, 'E', DTENTRSAID, DTEMISSAO) BETWEEN :DTINICIAL AND :DTFINAL AND N.CDEMPRESA = :CDEMPRESA AND N.CDINSCESTA = :CDINSCESTA AND N.NRORG = :NRORG AND N.IDSTATUS <> 'C' AND N.IDSTATUSNFE <> 'D' AND N.IDENTRSAIDOP IN ('S', 'E') AND I.CDTIPOOPER = N.CDTIPOOPER AND I.IDENTRSAIDOP = N.IDENTRSAIDOP AND I.NRORG = N.NRORG AND I.CDIMPOSTO = IM.CDIMPOSTO AND I.NRORG = IM.NRORG AND :CDIMPOSTO = IM.CDIMPOSTONFE AND P.NRORG = IM.NRORG AND P.IDBLOQNFSEMINCID = 'S' AND NVL(N.IDSISTEMA,'DFS') <> 'REC' AND NVL(N.IDSISTEMA,'DFS') <> 'PAG' AND NVL(N.IDSISTEMA,'DFS') <> 'CMP' AND NVL(N.IDSISTEMA,'DFS') <> 'SUP' AND NVL(N.IDSISTEMA,'DFS') <> 'TMP' AND NVL(N.IDSISTEMA,'DFS') <> 'FIS' AND NOT EXISTS (SELECT IMPOSTONF.CDFILIAL, IMPOSTONF.NRLANCTONF FROM IMPOSTONF WHERE IMPOSTONF.CDFILIAL = N.CDFILIAL AND IMPOSTONF.NRLANCTONF = N.NRLANCTONF AND IMPOSTONF.NRORG = N.NRORG AND IMPOSTONF.CDIMPOSTO = I.CDIMPOSTO AND IMPOSTONF.NRORG = I.NRORG AND IMPOSTONF.NRORG = :NRORG)";

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        return $std->fetch();
    }

    public function getNotaPendenteContribuicoes($params) {
        $sql = "SELECT I.CDFILIAL, I.NRLANCTONF FROM NOTAFISCAL N, IMPOSTONF I, IMPOSTO IM, PARAMFISCAL P WHERE IDSTATUS = 'P' AND IDSTATUSNFE <> 'D' AND CDEMPRESA = :CDEMPRESA AND DECODE(:IDFORMAPUR, 'D', DTENTRSAID, 'E', DTEMISSAO, DECODE(IDENTRSAIDOP, 'E', DTENTRSAID, DTEMISSAO)) BETWEEN :DTINICIAL AND :DTFINAL AND IDENTRSAIDOP IN('E', 'S') AND I.CDFILIAL = N.CDFILIAL AND I.NRLANCTONF = N.NRLANCTONF AND I.NRORG = N.NRORG AND N.NRORG = :NRORG AND I.CDIMPOSTO = IM.CDIMPOSTO AND I.NRORG = IM.NRORG AND :CDIMPOSTO = IM.CDIMPOSTONFE AND P.NRORG = N.NRORG AND P.IDBLOQNFPENDE = 'S' UNION ALL SELECT DISTINCT N.CDFILIAL, N.NRLANCTONF FROM NOTAFISCAL N, IMPOBRIGTPOPER I, IMPOSTO IM, PARAMFISCAL P WHERE DECODE(:IDFORMAPUR, 'D', DTENTRSAID, 'E', DTEMISSAO, DECODE(N.IDENTRSAIDOP, 'E', DTENTRSAID, DTEMISSAO)) BETWEEN :DTINICIAL AND :DTFINAL AND CDEMPRESA = :CDEMPRESA AND N.IDSTATUS <> 'C' AND IDSTATUSNFE <> 'D' AND N.IDENTRSAIDOP IN ('S', 'E') AND I.CDTIPOOPER = N.CDTIPOOPER AND I.IDENTRSAIDOP = N.IDENTRSAIDOP AND I.NRORG = N.NRORG AND I.CDIMPOSTO = IM.CDIMPOSTO AND I.NRORG = IM.NRORG AND :CDIMPOSTO = IM.CDIMPOSTONFE AND NVL(N.IDSISTEMA,'DFS') <> 'REC' AND NVL(N.IDSISTEMA,'DFS') <> 'PAG' AND NVL(N.IDSISTEMA,'DFS') <> 'CMP' AND NVL(N.IDSISTEMA,'DFS') <> 'SUP' AND NVL(N.IDSISTEMA,'DFS') <> 'TMP' AND NVL(N.IDSISTEMA,'DFS') <> 'FIS' AND P.NRORG = N.NRORG AND P.IDBLOQNFSEMINCID = 'S' AND NOT EXISTS (SELECT IMPOSTONF.CDFILIAL, IMPOSTONF.NRLANCTONF FROM IMPOSTONF WHERE IMPOSTONF.CDFILIAL = N.CDFILIAL AND IMPOSTONF.NRLANCTONF = N.NRLANCTONF AND IMPOSTONF.CDIMPOSTO = I.CDIMPOSTO AND IMPOSTONF.NRORG = N.NRORG)";

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        return $std->fetch();
    }

    public function getPreparacaoPagamento($params) {
        $sql = "SELECT MAX(PREP_PAGAMENTO) AS PREPPAGAMENTO FROM( SELECT 'S' AS PREP_PAGAMENTO FROM RELACMAPANF R WHERE R.NRSEQUMAPAPU = :NRSEQUMAPAPU AND R.NRORG = :NRORG UNION SELECT 'S' AS PREP_PAGAMENTO FROM MAPAAPURAC M WHERE M.NRSEQUMAPAPU = :NRSEQUMAPAPU AND M.NRORG = :NRORG AND M.NRLANCTONF IS NOT NULL UNION SELECT 'S' AS PREP_PAGAMENTO FROM DOCARRECADPAG DAP WHERE DAP.NRSEQUMAPAPU = :NRSEQUMAPAPU AND DAP.NRORG = :NRORG AND DAP.NRLANCTONF IS NOT NULL)";

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        return $std->fetch()["PREPPAGAMENTO"];
    }

    public function getPrxDtIniMapa($params) {
        $sql = "SELECT MAX(DTINIPERIODO) AS DTINIPERIODO FROM (SELECT MAX(M.DTFIMPERIODO)+1 AS DTINIPERIODO FROM MAPAAPURAC M WHERE M.CDIMPOSTO = :CDIMPOSTO AND M.CDEMPRESA = :CDEMPRESA AND((M.CDINSCESTA = :CDINSCESTA AND :IDTIPOAPURA = 'E') OR (M.CDINSCMUNI = :CDINSCMUNI AND :IDTIPOAPURA = 'M') OR (:CDINSCESTA IS NULL AND :CDINSCMUNI IS NULL AND NVL(:IDTIPOAPURA,'F') = 'F')) AND M.NRORG = :NRORG UNION SELECT MAX(M.DTFIMPERIODO)+1 AS DTINIPERIODO FROM MAPAAPURACSN M WHERE M.CDEMPRESA = :CDEMPRESA AND :IDTIPOAPURA = 'S' AND M.NRORG = :NRORG)";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch()["DTINIPERIODO"];
    }
    
    public function getSomaArrecadacaoFiscalIcmsSt($params) {
        $sql = " SELECT NVL(SUM(VRRECEITA),0) AS VALORRECEITA FROM DETAUFMAPAEST WHERE NRSEQUMAPAPU= :NRSEQUMAPAPU AND NRSEQMAPAAPUREST= :NRSEQMAPAAPUREST AND CDPAIS = :CDPAIS AND SGESTADO =:SGESTADO";

        $statement = $this->connection->prepare($sql);
        $statement->execute($params);

        return $statement->fetch();
    }
    
    public function getSomasDetalhamentoGeral($params) {
        $sql = "SELECT NVL(SUM(DECODE(I.IDTIPOITMAPR,'OC',ROUND(I.VRITEMMAPR,2),0) ),0) AS VROUTROSCREDITOS, NVL(SUM(DECODE(I.IDTIPOITMAPR,'ED',ROUND(I.VRITEMMAPR,2),0) ),0) AS VRESTORNODEBITO, NVL(SUM(DECODE(I.IDTIPOITMAPR,'OD',ROUND(I.VRITEMMAPR,2),0) ),0) AS VROUTROSDEBITOS, NVL(SUM(DECODE(I.IDTIPOITMAPR,'EC',ROUND(I.VRITEMMAPR,2),0) ),0) AS VRESTORNOCREDITO, NVL(SUM(DECODE(I.IDTIPOITMAPR,'DD',ROUND(I.VRITEMMAPR,2),0) ),0) AS VRDEDUCOES, NVL(SUM(DECODE(I.IDTIPOITMAPR,'DA',ROUND(I.VRITEMMAPR,2),0) ),0) AS VRDIFERENCIAL, NVL(SUM(DECODE(I.IDTIPOITMAPR,'DE',ROUND(I.VRITEMMAPR,2),0) ),0) AS VRDEBESPECIAL, NVL(SUM(DECODE(I.IDTIPOITMAPR,'VI',ROUND(I.VRITEMMAPR,2),0) ),0) AS VRINFORMATIVO FROM ITMAPARECUP I, MAPAAPURAC M WHERE I.NRSEQUMAPAPU =:P_SEQUMAPAPU AND I.NRSEQUMAPAPU = M.NRSEQUMAPAPU";

        $statement = $this->connection->prepare($sql);
        $statement->execute($params);

        return $statement->fetch();
    }
    
    public function getSomaImpostosIcmsSt($params) {
        $sql = "SELECT NVL(SUM(VRIMPARECOLHER),0) AS SOMAIMPOSTO, NVL(SUM(VRSALDOCREDOR),0) AS SOMACREDOR FROM MAPAAPURESTADO WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU AND NRORG = :NRORG ";

        $statement = $this->connection->prepare($sql);
        $statement->execute($params);

        return $statement->fetch();
    }
    
    public function getSomasDetalhamentoIcmsDifalFcp($params) {
        $sql = "SELECT NVL(SUM(DECODE(IDTIPOITMAPR,'OC',ROUND(VRITEMMAPR,2),0)),0) AS VROUTROSCREDITOS, NVL(SUM(DECODE(IDTIPOITMAPR,'ED',ROUND(VRITEMMAPR,2),0)),0) AS VRESTORNODEBITO, NVL(SUM(DECODE(IDTIPOITMAPR,'OD',ROUND(VRITEMMAPR,2),0)),0) AS VROUTROSDEBITOS, NVL(SUM(DECODE(IDTIPOITMAPR,'EC',ROUND(VRITEMMAPR,2),0)),0) AS VRESTORNOCREDITO, NVL(SUM(DECODE(IDTIPOITMAPR,'DD',ROUND(VRITEMMAPR,2),0)),0) AS VRDEDUCOES FROM ITMAPARECUPNC WHERE NRSEQUMAPAPU = :P_NRSEQUMAPAPU AND NRSEQMAPAPURESTNC = :P_NRSEQMAPAPURESTNC AND IDAJUSTENC = :P_IDAJUSTENC AND NRORG = :P_NRORG";

        $statement = $this->connection->prepare($sql);
        $statement->execute($params);

        return $statement->fetch();
    }
    
    public function getSomasDetalhamentoIcmsSt($params) {
        $sql = "SELECT NVL(SUM(DECODE(IDTPAJUSTE,'OC',ROUND(VRAJUSTEAPURSG,2),0) ),0) AS VROUTROSCREDITOS, NVL(SUM(DECODE(IDTPAJUSTE,'OD',ROUND(VRAJUSTEAPURSG,2),0) ),0) AS VROUTROSDEBITOS, NVL(SUM(DECODE(IDTPAJUSTE,'DD',ROUND(VRAJUSTEAPURSG,2),0) ),0) AS VRDEDUZFECP, NVL(SUM(DECODE(IDTPAJUSTE,'DE',ROUND(VRAJUSTEAPURSG,2),0) ),0) AS VRDEBESPFECP FROM AJUSTMAPAAPURSG WHERE NRSEQUMAPAPU =:NRSEQUMAPAPU AND NRORG =:NRORG AND NRSEQMAPAAPUREST =:NRSEQMAPAAPUREST AND CDPAIS =:CDPAIS AND SGESTADO =:SGESTADO";

        $statement = $this->connection->prepare($sql);
        $statement->execute($params);

        return $statement->fetch();
    }
    
    public function getSomasItensAjustesContribuicoes($params) {
        $sql = "SELECT SUM(VRAJUSTECREDENTR) AS VRAJUSTECREDENTR, SUM(VRAJUSTEDEBENTR) AS VRAJUSTEDEBENTR, SUM(VRAJUSTECREDSAIDDI + VRAJUSTECREDSAIDDB) AS VRAJUSTECREDSAID, SUM(VRAJUSTEDEBSAIDDI + VRAJUSTEDEBSAIDDB) AS VRAJUSTEDEBSAID, SUM(VRAJUSTECREDSAIDDI) AS VRAJUSTECREDSAIDDI, SUM(VRAJUSTEDEBSAIDDI) AS VRAJUSTEDEBSAIDDI, SUM(VRAJUSTECREDSAIDDB) AS VRAJUSTECREDSAIDDB, SUM(VRAJUSTEDEBSAIDDB) AS VRAJUSTEDEBSAIDDB FROM ( SELECT NVL(SUM(DECODE(IDTPAJUSTE,'1',VRAJUSTE,0) ),0) AS VRAJUSTECREDENTR, NVL(SUM(DECODE(IDTPAJUSTE,'0',VRAJUSTE,0) ),0) AS VRAJUSTEDEBENTR, 0 AS VRAJUSTECREDSAIDDI, 0 AS VRAJUSTEDEBSAIDDI, 0 AS VRAJUSTECREDSAIDDB, 0 AS VRAJUSTEDEBSAIDDB FROM AJUSTEAPURCONTR WHERE NRSEQUMAPAPU =:NRSEQUMAPAPU AND NRORG =:NRORG AND IDINDICAJUSTE = 'C' AND IDFORMAPUR = 'C' GROUP BY NRSEQUMAPAPU UNION ALL SELECT 0 AS VRAJUSTECREDENTR, 0 AS VRAJUSTEDEBENTR, NVL(SUM(DECODE(IDTPAJUSTE,'1',VRAJUSTE,0) ),0) AS VRAJUSTECREDSAIDDI, NVL(SUM(DECODE(IDTPAJUSTE,'0',VRAJUSTE,0) ),0) AS VRAJUSTEDEBSAIDDI, 0 AS VRAJUSTECREDSAIDDB, 0 AS VRAJUSTEDEBSAIDDB FROM AJUSTEAPURCONTR WHERE NRSEQUMAPAPU =:NRSEQUMAPAPU AND NRORG =:NRORG AND IDINDICAJUSTE = 'DI' AND IDFORMAPUR = 'C' UNION ALL SELECT 0 AS VRAJUSTECREDENTR, 0 AS VRAJUSTEDEBENTR, 0 AS VRAJUSTECREDSAIDDI, 0 AS VRAJUSTEDEBSAIDDI, NVL(SUM(DECODE(IDTPAJUSTE,'1',VRAJUSTE,0) ),0) AS VRAJUSTECREDSAIDDB, NVL(SUM(DECODE(IDTPAJUSTE,'0',VRAJUSTE,0) ),0) AS VRAJUSTEDEBSAIDDB FROM AJUSTEAPURCONTR WHERE NRSEQUMAPAPU =:NRSEQUMAPAPU AND NRORG =:NRORG AND IDINDICAJUSTE = 'DB' AND IDFORMAPUR = 'C' )";

        $statement = $this->connection->prepare($sql);
        $statement->execute($params);

        return $statement->fetch();
    }
    
    public function getSomasItensAjustesContribuicoesPag($params) {
        $sql = "SELECT SUM(VRAJCREDENTRPAG) AS VRAJCREDENTRPAG, SUM(VRAJDEBENTRPAG) AS VRAJDEBENTRPAG, SUM(VRAJCREDSAIDDIPAG + VRAJCREDSAIDDBPAG) AS VRAJUSTECREDSAID, SUM(VRAJDEBSAIDDIPAG + VRAJDEBSAIDDBPAG) AS VRAJUSTEDEBSAID, SUM(VRAJCREDSAIDDIPAG) AS VRAJCREDSAIDDIPAG, SUM(VRAJDEBSAIDDIPAG) AS VRAJDEBSAIDDIPAG, SUM(VRAJCREDSAIDDBPAG) AS VRAJCREDSAIDDBPAG, SUM(VRAJDEBSAIDDBPAG) AS VRAJDEBSAIDDBPAG FROM ( SELECT NVL(SUM(DECODE(IDTPAJUSTE,'1',VRAJUSTE,0) ),0) AS VRAJCREDENTRPAG, NVL(SUM(DECODE(IDTPAJUSTE,'0',VRAJUSTE,0) ),0) AS VRAJDEBENTRPAG, 0 AS VRAJCREDSAIDDIPAG, 0 AS VRAJDEBSAIDDIPAG, 0 AS VRAJCREDSAIDDBPAG, 0 AS VRAJDEBSAIDDBPAG FROM AJUSTEAPURCONTR WHERE NRSEQUMAPAPU =:NRSEQUMAPAPU AND NRORG =:NRORG AND IDINDICAJUSTE = 'C' AND IDFORMAPUR = 'P' GROUP BY NRSEQUMAPAPU UNION ALL SELECT 0 AS VRAJCREDENTRPAG, 0 AS VRAJDEBENTRPAG, NVL(SUM(DECODE(IDTPAJUSTE,'1',VRAJUSTE,0) ),0) AS VRAJCREDSAIDDIPAG, NVL(SUM(DECODE(IDTPAJUSTE,'0',VRAJUSTE,0) ),0) AS VRAJDEBSAIDDIPAG, 0 AS VRAJCREDSAIDDBPAG, 0 AS VRAJDEBSAIDDBPAG FROM AJUSTEAPURCONTR WHERE NRSEQUMAPAPU =:NRSEQUMAPAPU AND NRORG =:NRORG AND IDINDICAJUSTE = 'DI' AND IDFORMAPUR = 'P' UNION ALL SELECT 0 AS VRAJCREDENTRPAG, 0 AS VRAJDEBENTRPAG, 0 AS VRAJCREDSAIDDIPAG, 0 AS VRAJDEBSAIDDIPAG, NVL(SUM(DECODE(IDTPAJUSTE,'1',VRAJUSTE,0) ),0) AS VRAJCREDSAIDDBPAG, NVL(SUM(DECODE(IDTPAJUSTE,'0',VRAJUSTE,0) ),0) AS VRAJDEBSAIDDBPAG FROM AJUSTEAPURCONTR WHERE NRSEQUMAPAPU =:NRSEQUMAPAPU AND NRORG =:NRORG AND IDINDICAJUSTE = 'DB' AND IDFORMAPUR = 'P' )";

        $statement = $this->connection->prepare($sql);
        $statement->execute($params);

        return $statement->fetch();
    }

    public function getSomasItensDetalhamentoContribuicoes($params) {
        $sql = "SELECT SUM(VRCREDPERANT) AS VRCREDPERANT, SUM(VRCOMPENSA) AS VRCOMPENSA, SUM(VRDEDUCAO) AS VRDEDUCAO FROM( SELECT NVL(SUM(VRITEMDETAPU), 0) VRCREDPERANT , 0 AS VRCOMPENSA, 0 AS VRDEDUCAO FROM ITDETAPUCONTR WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU AND NRORG = :NRORG AND IDTIPODETAPU = 'CA' UNION ALL SELECT 0 AS VRCREDPERANT, NVL(SUM(VRITEMDETAPU), 0) AS VRCOMPENSA, 0 AS VRDEDUCAO FROM ITDETAPUCONTR WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU AND NRORG = :NRORG AND IDTIPODETAPU = 'CO' UNION ALL SELECT 0 AS VRCREDPERANT, 0 AS VRCOMPENSA, NVL(SUM(VRITEMDETAPU), 0) AS VRDEDUCAO FROM ITDETAPUCONTR WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU AND NRORG = :NRORG AND IDTIPODETAPU = 'DD')";

        $statement = $this->connection->prepare($sql);
        $statement->execute($params);

        return $statement->fetch();
    }

    public function getVendaPendente($params) {
        $sql = "SELECT DISTINCT V.CDFILIAL, V.DTENTRVENDA, V.CDCAIXA, PA.IDPREVALIDCUPOM FROM VENDA V, FILIAL F, PARAVEND PA, PARAMFISCAL P WHERE V.IDTPEMISVEND IN('N','S') AND V.CDFILIAL = F.CDFILIAL AND V.NRORG = F.NRORG AND V.NRORG = :NRORG AND V.DTENTRVENDA BETWEEN :DTINICIAL AND :DTFINAL AND V.IDTPAMBNFCE = '1' AND V.IDSTATUSNFCE IN ('A','C') AND V.IDSITUVENDA = 'O' AND F.CDEMPRESA = :CDEMPRESA AND F.CDINSCESTA = :CDINSCESTA AND F.CDEMPRESA = V.CDEMPRESA AND V.IDAPROVACAONFCE = 'P' AND V.CDFILIAL = PA.CDFILIAL AND V.NRORG = PA.NRORG AND P.NRORG = V.NRORG AND P.IDBLOQNFPENDE = 'S' AND PA.IDPREVALIDCUPOM = 'S' UNION ALL SELECT DISTINCT V.CDFILIAL, V.DTENTRVENDA, V.CDCAIXA, PA.IDPREVALIDCUPOM FROM REDUCAOZ R, VENDA V, FILIAL F, PARAVEND PA, PARAMFISCAL P WHERE TRUNC(R.DTREDUCAOZ) = TRUNC(V.DTENTRVENDA) AND R.CDFILIAL = V.CDFILIAL AND R.CDCAIXA = V.CDCAIXA AND R.NRORG = V.NRORG AND R.NRORG = :NRORG AND (V.IDTPEMISVEND NOT IN ('N','S') OR V.IDTPEMISVEND IS NULL) AND V.DTENTRVENDA BETWEEN :DTINICIAL AND :DTFINAL AND V.IDSITUVENDA = 'O' AND F.CDEMPRESA = :CDEMPRESA AND F.CDINSCESTA = :CDINSCESTA AND F.CDEMPRESA = V.CDEMPRESA AND F.NRORG = V.NRORG AND R.IDSTATUS = 'P' AND V.CDFILIAL = PA.CDFILIAL AND F.CDFILIAL = PA.CDFILIAL AND F.NRORG = PA.NRORG AND P.IDBLOQNFPENDE = 'S' AND P.NRORG = V.NRORG AND PA.IDPREVALIDCUPOM = 'S'";

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        return $std->fetch();
    }

    public function getVendaPendenteContribuicoes($params) {
        $sql = "SELECT DISTINCT V.CDFILIAL, V.DTENTRVENDA, V.CDCAIXA, PA.IDPREVALIDCUPOM FROM VENDA V, FILIAL F, PARAVEND PA WHERE V.IDTPEMISVEND IN('N','S') AND V.CDFILIAL = F.CDFILIAL AND V.NRORG = F.NRORG AND V.NRORG = :NRORG AND V.DTENTRVENDA BETWEEN :DTINICIAL AND :DTFINAL AND V.IDTPAMBNFCE = '1' AND V.IDSTATUSNFCE IN ('A','C') AND V.IDSITUVENDA = 'O' AND F.CDEMPRESA = :CDEMPRESA AND F.CDEMPRESA = V.CDEMPRESA AND V.IDAPROVACAONFCE = 'P' AND F.CDFILIAL = PA.CDFILIAL AND F.NRORG = PA.NRORG AND PA.IDPREVALIDCUPOM = 'S' UNION ALL SELECT DISTINCT V.CDFILIAL, V.DTENTRVENDA, V.CDCAIXA, PA.IDPREVALIDCUPOM FROM REDUCAOZ R, VENDA V, FILIAL F, PARAVEND PA WHERE TRUNC(R.DTREDUCAOZ) = TRUNC(V.DTENTRVENDA) AND R.CDFILIAL = V.CDFILIAL AND R.CDCAIXA = V.CDCAIXA AND R.NRORG = V.NRORG AND R.NRORG = :NRORG AND (V.IDTPEMISVEND NOT IN ('N','S') OR V.IDTPEMISVEND IS NULL) AND V.DTENTRVENDA BETWEEN :DTINICIAL AND :DTFINAL AND V.IDSITUVENDA = 'O' AND F.CDEMPRESA = :CDEMPRESA AND F.CDEMPRESA = V.CDEMPRESA AND F.NRORG = V.NRORG AND R.IDSTATUS = 'P' AND V.CDFILIAL = PA.CDFILIAL AND F.CDFILIAL = PA.CDFILIAL AND PA.IDPREVALIDCUPOM = 'S'";

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        return $std->fetch();
    }

    public function insertDetapuracontr($params) {
        $sql = "INSERT INTO DETAPURACONTR(NRSEQUMAPAPU, NRORG, VRCREDENTR, VRDEDUCAO, VRCREDATIVIMOB, VRDEBNCUMULA, VRDEBCUMULA, VRDEBECF, VRCOMPENSA, VROUTRECCONT, VRSALDOCRED, VRCREDPERANT, VRCANCDEVOL) VALUES(:NRSEQUMAPAPU, :NRORG, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0)";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function insertInfadicmapa($params) {
        $sql = "INSERT INTO INFADICMAPA(NRORG, NRSEQUMAPAPU,NRSEQINFADIC,CDINFADICMAPA,DSINFADICMAPA,VRINFADICMAPA) VALUES(:P_NRORG, :P_NRSEQUMAPAPU,:P_NRSEQINFADIC,:P_CDINFADICMAPA,:P_DSINFADICMAPA,:P_VRINFADICMAPA)";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function insertDetitmaparecup($params) {
        $sql = "INSERT INTO DETITMAPARECUP
                    (NRSEQDETITMAPA, NRSEQUMAPAPU, IDTIPOITMAPR, NRSEQITMAPR,
                    CDFILIAL, NRLANCTONF, NRSEQITPROD, CDIMPOSTO, NRITPROIMPOS, NRORG)
                VALUES
                    (:P_NRSEQDETITMAPA,:P_NRSEQUMAPAPU,:P_IDTIPOITMAPR,:P_NRSEQITMAPR,
                    :P_CDFILIAL,:P_NRLANCTONF,:P_NRSEQITPROD,:P_CDIMPOSTO,:P_NRITPROIMPOS, :P_NRORG)";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function insertItmaparecup($params) {
        $sql = "INSERT INTO ITMAPARECUP
                    (NRORG, NRSEQITMAPR, DSITEMMAPR, VRITEMMAPR, VROUTROSITMAPR,
                    NRLANCTONF,CDFILIAL, IDCOMPOEC197, CDAJUSTEITMAPA, NRSEQUMAPAPU, IDTIPOITMAPR)
                VALUES
                    (:NRORG,:NRSEQITMAPR,:DSITEMMAPR,:VRITEMMAPR, :VROUTROSITMAPR,
                    :NRLANCTONF,:CDFILIAL, :IDCOMPOEC197,:CDAJUSTEITMAPA,:NRSEQUMAPAPU,:IDTIPOITMAPR)";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function updateItmaparecup($params) {
        $sql = "UPDATE ITMAPARECUP SET 
                       DSITEMMAPR     = :DSITEMMAPR,
                       VRITEMMAPR     = :VRITEMMAPR,
                       VROUTROSITMAPR = :VROUTROSITMAPR,
                       NRLANCTONF     = :NRLANCTONF,
                       CDFILIAL       = :CDFILIAL,
                       IDCOMPOEC197   = :IDCOMPOEC197,
                       CDAJUSTEITMAPA = :CDAJUSTEITMAPA
                WHERE  NRSEQUMAPAPU      = :NRSEQUMAPAPU
                       AND IDTIPOITMAPR  = :IDTIPOITMAPR
                       AND NRSEQITMAPR   = :NRSEQITMAPR
                       AND NRORG         = :NRORG";


        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function salvarCreditoAnteriorDifalFcp($params) {
        $sql = "UPDATE MAPARECUPNC SET VRSLDCRANTEDIFAL = :VRSLDCRANTEDIFAL,
                       VRSLDCRANTEFCP = :VRSLDCRANTEFCP
                WHERE  NRSEQMAPARECUPNC = :NRSEQMAPARECUPNC
                       AND NRORG = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function updateSomaAjustmapaapursg($params) {
        $sql = "UPDATE AJUSTMAPAAPURSG
                SET VRAJUSTEAPURSG      = :VALOR
                WHERE NRSEQUMAPAPU      = :NRSEQUMAPAPU
                    AND IDTPAJUSTEAPSG  = :IDTPAJUSTEAPSG
                    AND NRSEQAJUSAPURSG = :NRSEQAJUSAPURSG
                    AND NRORG           = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function updateSomaItensComposicao($params) {
        $sql = "UPDATE ITMAPARECUP
                SET VRITEMMAPR = :VALOR
                WHERE NRSEQUMAPAPU   = :NRSEQUMAPAPU
                    AND IDTIPOITMAPR = :IDTIPOITMAPR
                    AND NRSEQITMAPR = :NRSEQITMAPR
                    AND NRORG = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    
    public function updateDetapuracontr($params) {
        $sql = "UPDATE DETAPURACONTR
                SET VRCREDPERANT = :VRCREDPERANT
                WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU
                    AND NRORG= :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function updateCreditoAnterirorIcmsSt($params) {
        $sql = "UPDATE MAPAAPURESTADO
                SET VRCREDANTERIOR  = :VRCREDANTERIOR
                WHERE NRSEQUMAPAPU       = :NRSEQUMAPAPU
                    AND NRSEQMAPAAPUREST = :NRSEQMAPAAPUREST
                    AND CDPAIS           = :CDPAIS
                    AND SGESTADO         = :SGESTADO
                    AND NRORG            = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    
    public function updateParclancativ($params) {
        $sql = "UPDATE PARCLANCATIV
                    SET VRCRAPRPARCLAN = NULL,
                    NRSEQUMAPAPU       = NULL
                WHERE CDFILIAL      = :CDFILIAL
                    AND NRLANCTONF  = :NRLANCTONF
                    AND NRSEQITPROD = :NRSEQITPROD
                    AND NRPARCATIV  = :NRPARCATIV";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function updateMaparecup($params) {
        $sql = "UPDATE MAPARECUP
                SET VRSLDCRANTE = :VRSLDCRANTE
                WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU
                    AND NRORG= :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
 
    public function insertItdetapucontr($params) {
        $sql = " INSERT INTO ITDETAPUCONTR (
                    NRSEQUMAPAPU, IDTIPODETAPU, NRSEQITDETAPU, DSITEMDETAPU, VRITEMDETAPU, IDCUMUPISCOFIL, CDCONTRATEIO, CDEMPRESA, CDLOTE
                )
                VALUES
                    (:P_NRSEQUMAPAPU, 'CA', LPAD(NVL(:V_SEQITCREANT,1),4,'0'), 'CRÉDITO DE PERÍODO ANTERIOR', :V_VRCREMAPANT, 'S', :P_CDCONTRATEIO, :P_CDEMPRESA, :P_CDLOTE)";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function insertMaparecup($params) {
        $sql = "INSERT INTO MAPARECUP(NRSEQUMAPAPU, NRORG,VRNORMDEBI,VROUTRDEBI,VRESTOCRED,VRTOTADEBI,VRNORMCRED,VROUTRCRED, VRESTODEBI, VRTOTACRED , VRDEDUCAO , VRSLDCRANTE , VRSALDOCRED , VRDIFALIQU , VRDEBESPECIAL, VRINFORMATIVO, VRSALDODEBI , VRIMPCARGATRIBM , VRFATBRUTOMAPR, VRDIFALNC, VRFCPNC ) VALUES(:NRSEQUMAPAPU, :NRORG, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0)";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function insertMapaapuracContribuicoes($params) {
        $sql = "INSERT INTO MAPAAPURAC(NRORG, CDEMPRESA, CDIMPOSTO, DTINIPERIODO, DTFIMPERIODO, NRSEQUMAPAPU, NMMAPAAPUR,VRTTCTBLDEB,VRTTBACALDEB,VRTOTAIMPOS) VALUES (:NRORG, :CDEMPRESA, :CDIMPOSTO, :DTINIPERIODO, :DTFIMPERIODO, :NRSEQUMAPAPU, :NMMAPAAPUR, 0,0,0)";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function saveArrecadacaoContribuicoes($params) {
        $sql = "UPDATE MAPAAPURAC SET DTVENCGUIA = :DTVENCGUIA, CDRECENCUMU = :CDRECENCUMU, CDRECECUMU = :CDRECECUMU, CDVARIACAO = :CDVARIACAO, IDPERIODICREC = :IDPERIODICREC, IDDEBSCPINC = :IDDEBSCPINC, DSHISTGUIA = :DSHISTGUIA, VRTOTAIMPOS = :VRTOTAIMPOS, VRJUROGUIA = :VRJUROGUIA, VRMULTAGUIA = :VRMULTAGUIA, VRTOTAGUIA = :VRTOTAGUIA WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function salvarArrecadacaoGeral($params) {
        $sql = "UPDATE MAPAAPURAC SET CDRECEGUIA = :CDRECEGUIA, DTVENCGUIA = :DTVENCGUIA, DSHISTGUIA = :DSHISTGUIA, VRTOTAIMPOS = :VRTOTAIMPOS, VRJUROGUIA = :VRJUROGUIA, VRMULTAGUIA = :VRMULTAGUIA, VRTOTAGUIA = :VRTOTAGUIA WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function updateValoresDetalhamentoContribuicoes($params) {
        $sql = "UPDATE DETAPURACONTR SET VRCREDPERANT =:VRCREDPERANT, VRCOMPENSA =:VRCOMPENSA, VRDEDUCAO =:VRDEDUCAO, VRAJUSTECREDENTR =:VRAJUSTECREDENTR, VRAJUSTEDEBENTR =:VRAJUSTEDEBENTR, VRAJUSTECREDSAID =:VRAJUSTECREDSAID, VRAJUSTEDEBSAID =:VRAJUSTEDEBSAID, VRAJUSTECREDSAIDDI =:VRAJUSTECREDSAIDDI, VRAJUSTECREDSAIDDB =:VRAJUSTECREDSAIDDB, VRAJUSTEDEBSAIDDI =:VRAJUSTEDEBSAIDDI, VRAJUSTEDEBSAIDDB =:VRAJUSTEDEBSAIDDB, VRAJCREDENTRPAG =:VRAJCREDENTRPAG, VRAJDEBENTRPAG =:VRAJDEBENTRPAG, VRAJCREDSAIDPAG =:VRAJCREDSAIDPAG, VRAJDEBSAIDPAG =:VRAJDEBSAIDPAG, VRAJCREDSAIDDIPAG =:VRAJCREDSAIDDIPAG, VRAJDEBSAIDDIPAG =:VRAJDEBSAIDDIPAG, VRAJCREDSAIDDBPAG =:VRAJCREDSAIDDBPAG, VRAJDEBSAIDDBPAG =:VRAJDEBSAIDDBPAG, VRTOTCRED =:VRTOTCRED, VRTOTDEB =:VRTOTDEB, VRSALDOCRED =:VRSALDOCRED, VRTOTCONTR =:VRTOTCONTR, VRTOTCREDRPAG =:VRTOTCREDRPAG, VRTOTDEBRPAG =:VRTOTDEBRPAG, VRSALDOCREDRPAG =:VRSALDOCREDRPAG, VRSOMADEBCREDRPAG =:VRSOMADEBCREDRPAG WHERE NRSEQUMAPAPU =:NRSEQUMAPAPU AND NRORG =:NRORG";

        $statement = $this->connection->prepare($sql);
        $statement->execute($params);
    }

    public function updateValorTotalMapaContribuicoes($params) {
        $sql = "UPDATE MAPAAPURAC SET VRTOTAIMPOS = :VRTOTAIMPOS, VRTOTAGUIA = :VRTOTAGUIA WHERE NRSEQUMAPAPU = :NRSEQUMAPAPU AND NRORG = :NRORG";

        $statement = $this->connection->prepare($sql);
        $statement->execute($params);
    }
    
    public function getcodigoDetaufmapaest($params) {
        $sql = " SELECT NVL(MAX(NRSEQUDETUF),0)+1 AS NRSEQUDETUF FROM DETAUFMAPAEST WHERE NRSEQUMAPAPU = :P_NRSEQUMAPAPU AND CDPAIS = :P_CDPAIS AND NRSEQMAPAAPUREST = :NRSEQMAPAAPUREST AND SGESTADO = :P_SGESTADO";

        $statement = $this->connection->prepare($sql);
        $statement->execute($params);

        return $statement->fetch();
    }
    
    public function verifyUpdateAjusteApurContr($params) {
        $sql = "SELECT * FROM AJUSTEAPURCONTR WHERE NRSEQUMAPAPU =:NRSEQUMAPAPU AND NRSEQAJUSTE =:NRSEQAJUSTE AND NRORG =:NRORG";

        $statement = $this->connection->prepare($sql);
        $statement->execute($params);

        return $statement->fetch();
    }
    
    public function updateAjusteApurContr($params) {
        $sql = "UPDATE AJUSTEAPURCONTR SET DTAJUSTE =:DTAJUSTE, IDTPAJUSTE =:IDTPAJUSTE, CDAJUSTE =:CDAJUSTE, CDAJUSTEBC =:CDAJUSTEBC,
                                           NRPROCESSO =:NRPROCESSO, DSAJUSTE =:DSAJUSTE, VRAJUSTE =:VRAJUSTE, CDTPCREDPICOITE =:CDTPCREDPICOITE,
                                           IDCUMUPISCOFIL =:IDCUMUPISCOFIL, IDINDICAJUSTE =:IDINDICAJUSTE, CDSITUTRIBITNFE =:CDSITUTRIBITNFE,
                                           VRBASECALCAJ =:VRBASECALCAJ, CDCONTCTBL =:CDCONTCTBL, CDFILIAL =:CDFILIAL, IDAPROPRIACAO =:IDAPROPRIACAO,
                                           NRRECIBO =:NRRECIBO, CDCONTRATEIO =:CDCONTRATEIO, CDEMPRESA =:CDEMPRESA, CDLOTE =:CDLOTE   
                                     WHERE NRSEQUMAPAPU =:NRSEQUMAPAPU AND NRSEQAJUSTE =:NRSEQAJUSTE AND NRORG =:NRORG";

        $statement = $this->connection->prepare($sql);
        $statement->execute($params);
    }
    
    public function insertMapaapuimpofed($params) {
        $sql = "INSERT INTO MAPAAPUIMPOFED 
                    (NRSEQUMAPAPU , NRORG) 
                    VALUES (:NRSEQUMAPAPU, :NRORG)";

        $statement = $this->connection->prepare($sql);
        $statement->execute($params);
    }
    
    public function selectMapaapuimpofed($row) {
        $sql = "SELECT * FROM MAPAAPUIMPOFED 
                    WHERE NRSEQUMAPAPU= :NRSEQUMAPAPU";
         $params = array(
            "NRSEQUMAPAPU"  => $row["NRSEQUMAPAPU"]
        );
        $statement = $this->connection->prepare($sql);
        $statement->execute($params);
        return $statement->fetchAll();
    }
    
}
