<?php
namespace Teknisa\FIS\Services;

use Teknisa\FIS\Factories\Fis00800InventarioFiscalFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Zeedhi\Framework\DataSource\DataSet;

class Fis00800InventarioFiscalService {

  const ID_CUSTO_MEDIO_CONTABIL = 'C';
  const ID_POSICAO_ESTOQUE_CONSOLIDADA = 'P';

  protected $nrOrg;
  protected $environment;
  protected $newCode;
  protected $factory;

  public function __construct(Environment $environment, NewCode $newCode, Fis00800InventarioFiscalFactory $factory) {
    $this->environment = $environment;
    $this->nrOrg = $this->environment->getNrOrg();
    $this->newCode = $newCode;
    $this->factory = $factory;
  }

  public function generateNrSeq($tableName) {

    $nrSequencial = $this->newCode->getCodeByTableName($tableName, $this->nrOrg, 1, 0, true);

    return $nrSequencial;

  }

  public function validateInventarioFiscal($row) {
    // todo
  }

  public function importInventarioFiscal($row) {
    $dataSourceName = 'inventfisc_invfisc';
    $row['NRORG'] = $this->nrOrg;
    $importResults = array('successfulImports' => array(),
                           'noImports' => array());


    //O inventário considerado é Posição de Estoque Consolidada
    if($row['IDCONSIDINVENT'] === self::ID_POSICAO_ESTOQUE_CONSOLIDADA) {
      $queryResults = $this->factory->retrieveRowsQueryInvCons($row);
      $this->factory->deleteExistingInventarioFiscal($row, $queryResults);
      $this->factory->importInventarioFiscalInvCons($row, $queryResults);
    }

    //Popula array importResults, que guarda os códigos de inscrição estadual
    //aos quais houveram importações,
    //e aos quais não houveram.
    foreach($row['CDINSCESTA'] as $CDINSCESTA) {
      if (\Zeedhi\Framework\Util\Functions::arrayKeyExists($CDINSCESTA, $queryResults)) {
        $importResults['successfulImports'][] = $CDINSCESTA;
      } else {
        $importResults['noImports'][] = $CDINSCESTA;
      }
    }

    $dataSet = new DataSet($dataSourceName, $importResults);

    return $dataSet;


  }



}