/* Sistemas Integrados TECNISA
   Planejamento Alimentao Industrial

Nome: REQUISICAO_CENTRAL

Descrio:
Clculo do Consumo Planejado (Cardpio, Consumo por Servio Fixo ou
Percapita) atravs da stored procedure CONSUMO_PLANEJADO e gravao na
tabela PREVRETI.

P_FILIAL       - Codigo da Filial
P_SERVICOS     - String contendo sequencia de Servios a serem calculados
P_DTINICIAL    - Data inicial
P_DTFINAL      - Data final
P_IDARQUIVO    - Identificador da tabela a ser gravada
                 "P" -> PREVRETI
                 "C" -> CONSPLAN
                 "A" -> AMBAS
P_IDPRODUTOS   - Identificador dos produtos a serem gravados.
                 Formato "XXX"
                 1 posio = "C" -> Cardpio
                 2 posio = "F" -> Consumo por Servio Fixo
                 3 posio = "P" -> Consumo por Servio Percapita
P_IDSEPPRATO   - Identificador de requisio analtica, ou seja, separada
                 por prato ou por setor, consumo fixo e consumo percapita.
                 Formato "S" (setor), "P" (prato) ou "N" (n/a).
P_PEACRESCIMO  - Percentual de acrscimo
P_IDARREDOND   - Identificador de utilizao do arredondamento
                 para requisio do Produto. Formato "S" ou "N"
P_NRCONSPLAN   - Nmero sequencial a ser utilizado para gravao dos dados
P_CDPRODUTOINI - Cdigo do Produto inicial
P_CDPRODUTOFIN - Cdigo do Produto final
P_CDOPERADOR   - Cdigo do Operador
P_DTHRCALCPR   - Data/hora do clculo
P_STDTINICIAL  - Lista de data inicial em string por servio
P_STDTFINAL    - Lista de data final em string por servio

Para aplicar e debugar
-- @H:\SISTEMAS\DBA\SQL\ORACLE\7115_PLASTP_REQUISICAO_ANALITICA_SETOR_PLA.SQL
-- SET SERVEROUTPUT ON
-- DBMS_OUTPUT.PUT_LINE('xx');

Criao:
01/10/10 - Alexis

*/

IF EXISTS(SELECT name FROM sysobjects
          WHERE name = 'REQUISICAO_CENTRAL' AND type = 'P')
  DROP PROCEDURE REQUISICAO_CENTRAL
  GO

CREATE PROCEDURE REQUISICAO_CENTRAL
  @P_CDCENTRAL     VARCHAR(4),
  @P_CDFILAGREG    VARCHAR(4000),
  @P_SERVICOS      VARCHAR(4000),
  @P_DTINICIAL     DATETIME,
  @P_DTFINAL       DATETIME,
  @P_IDARQUIVO     VARCHAR(1),
  @P_IDPRODUTOS    VARCHAR(3),
  @P_IDSEPPRATO    VARCHAR(1),
  @P_PEACRESCIMO   NUMERIC(15,6),
  @P_IDARREDOND    VARCHAR(1),
  @P_NRCONSPLAN    VARCHAR(10),
  @P_CDPRODUTOINI  VARCHAR(10),
  @P_CDPRODUTOFIN  VARCHAR(10),
  @P_CDOPERADOR    VARCHAR(12),
  @P_DTHRCALCPR    DATETIME,
  @P_STDTINICIAL   VARCHAR(2000),
  @P_STDTFINAL     VARCHAR(2000) 

AS

   DECLARE @V_CDSERVFILI    VARCHAR(4000);
   DECLARE @V_CDSERVFILIAUX VARCHAR(4000);
   DECLARE @V_CDPRODUTOFIN  VARCHAR(10);
   DECLARE @V_CDFILIAL      VARCHAR(4);


BEGIN
   SET @V_CDPRODUTOFIN = LEFT(@P_CDPRODUTOFIN + REPLICATE('z',10), 10);
      DECLARE C_FILIAIS CURSOR FOR
         SELECT CDFILIAL
           FROM FILIAL
          WHERE (CDFILCENTPME = @P_CDCENTRAL)
            AND (CHARINDEX (CDFILIAL, @P_CDFILAGREG) > 0 OR @P_CDFILAGREG = 'T')
      OPEN C_FILIAIS;
      FETCH NEXT FROM C_FILIAIS INTO @V_CDFILIAL;
      WHILE (@@FETCH_STATUS = 0) BEGIN
         SET @V_CDSERVFILI = '_';
            DECLARE C_SERVICO CURSOR FOR
               SELECT CDSERVFILI
                 FROM SERVICO
                WHERE CDFILIAL = @V_CDFILIAL
                  AND (CHARINDEX ('_' + CDFILIAL + CDSERVFILI + '_', @P_SERVICOS) > 0)
            OPEN C_SERVICO;
            FETCH NEXT FROM C_SERVICO INTO @V_CDSERVFILIAUX;
            WHILE (@@FETCH_STATUS = 0)  BEGIN
               SET @V_CDSERVFILI = @V_CDSERVFILI + @V_CDSERVFILIAUX + '_';
               FETCH NEXT FROM C_SERVICO INTO @V_CDSERVFILI;
            END;
            CLOSE C_SERVICO;
            DEALLOCATE C_SERVICO;

         EXEC CONSUMO_PLANEJADO_PLA @V_CDFILIAL,
                                    @V_CDSERVFILI,
                                    @P_DTINICIAL,
                                    @P_DTFINAL,
                                    @P_IDARQUIVO,
                                    @P_IDPRODUTOS,
                                    @P_IDSEPPRATO,
                                    @P_PEACRESCIMO,
                                    @P_IDARREDOND,
                                    @P_NRCONSPLAN,
                                    @P_CDPRODUTOINI,
                                    @V_CDPRODUTOFIN,
                                    @P_CDOPERADOR,
                                    @P_STDTINICIAL,
                                    @P_STDTFINAL;
         FETCH NEXT FROM C_FILIAIS INTO @V_CDFILIAL;
      END;
      CLOSE C_FILIAIS;
      DEALLOCATE C_FILIAIS;
END;
